/* automatically generated by rust-bindgen 0.70.1 */

#[repr(C)]
#[derive(Default)]
pub struct __IncompleteArrayField<T>(::std::marker::PhantomData<T>, [T; 0]);
impl<T> __IncompleteArrayField<T> {
    #[inline]
    pub const fn new() -> Self {
        __IncompleteArrayField(::std::marker::PhantomData, [])
    }
    #[inline]
    pub fn as_ptr(&self) -> *const T {
        self as *const _ as *const T
    }
    #[inline]
    pub fn as_mut_ptr(&mut self) -> *mut T {
        self as *mut _ as *mut T
    }
    #[inline]
    pub unsafe fn as_slice(&self, len: usize) -> &[T] {
        ::std::slice::from_raw_parts(self.as_ptr(), len)
    }
    #[inline]
    pub unsafe fn as_mut_slice(&mut self, len: usize) -> &mut [T] {
        ::std::slice::from_raw_parts_mut(self.as_mut_ptr(), len)
    }
}
impl<T> ::std::fmt::Debug for __IncompleteArrayField<T> {
    fn fmt(&self, fmt: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        fmt.write_str("__IncompleteArrayField")
    }
}
pub const __BITS_PER_LONG: u32 = 64;
pub const __BITS_PER_LONG_LONG: u32 = 64;
pub const __FD_SETSIZE: u32 = 1024;
pub const _IOC_NRBITS: u32 = 8;
pub const _IOC_TYPEBITS: u32 = 8;
pub const _IOC_SIZEBITS: u32 = 14;
pub const _IOC_DIRBITS: u32 = 2;
pub const _IOC_NRMASK: u32 = 255;
pub const _IOC_TYPEMASK: u32 = 255;
pub const _IOC_SIZEMASK: u32 = 16383;
pub const _IOC_DIRMASK: u32 = 3;
pub const _IOC_NRSHIFT: u32 = 0;
pub const _IOC_TYPESHIFT: u32 = 8;
pub const _IOC_SIZESHIFT: u32 = 16;
pub const _IOC_DIRSHIFT: u32 = 30;
pub const _IOC_NONE: u32 = 0;
pub const _IOC_WRITE: u32 = 1;
pub const _IOC_READ: u32 = 2;
pub const IOC_IN: u32 = 1073741824;
pub const IOC_OUT: u32 = 2147483648;
pub const IOC_INOUT: u32 = 3221225472;
pub const IOCSIZE_MASK: u32 = 1073676288;
pub const IOCSIZE_SHIFT: u32 = 16;
pub const KVM_SPSR_EL1: u32 = 0;
pub const KVM_SPSR_SVC: u32 = 0;
pub const KVM_SPSR_ABT: u32 = 1;
pub const KVM_SPSR_UND: u32 = 2;
pub const KVM_SPSR_IRQ: u32 = 3;
pub const KVM_SPSR_FIQ: u32 = 4;
pub const KVM_NR_SPSR: u32 = 5;
pub const PSCI_0_2_FN_BASE: u32 = 2214592512;
pub const PSCI_0_2_64BIT: u32 = 1073741824;
pub const PSCI_0_2_FN64_BASE: u32 = 3288334336;
pub const PSCI_0_2_POWER_STATE_ID_MASK: u32 = 65535;
pub const PSCI_0_2_POWER_STATE_ID_SHIFT: u32 = 0;
pub const PSCI_0_2_POWER_STATE_TYPE_SHIFT: u32 = 16;
pub const PSCI_0_2_POWER_STATE_TYPE_MASK: u32 = 65536;
pub const PSCI_0_2_POWER_STATE_AFFL_SHIFT: u32 = 24;
pub const PSCI_0_2_POWER_STATE_AFFL_MASK: u32 = 50331648;
pub const PSCI_1_0_EXT_POWER_STATE_ID_MASK: u32 = 268435455;
pub const PSCI_1_0_EXT_POWER_STATE_ID_SHIFT: u32 = 0;
pub const PSCI_1_0_EXT_POWER_STATE_TYPE_SHIFT: u32 = 30;
pub const PSCI_1_0_EXT_POWER_STATE_TYPE_MASK: u32 = 1073741824;
pub const PSCI_0_2_AFFINITY_LEVEL_ON: u32 = 0;
pub const PSCI_0_2_AFFINITY_LEVEL_OFF: u32 = 1;
pub const PSCI_0_2_AFFINITY_LEVEL_ON_PENDING: u32 = 2;
pub const PSCI_0_2_TOS_UP_MIGRATE: u32 = 0;
pub const PSCI_0_2_TOS_UP_NO_MIGRATE: u32 = 1;
pub const PSCI_0_2_TOS_MP: u32 = 2;
pub const PSCI_1_1_RESET_TYPE_SYSTEM_WARM_RESET: u32 = 0;
pub const PSCI_1_1_RESET_TYPE_VENDOR_START: u32 = 2147483648;
pub const PSCI_VERSION_MAJOR_SHIFT: u32 = 16;
pub const PSCI_VERSION_MINOR_MASK: u32 = 65535;
pub const PSCI_VERSION_MAJOR_MASK: i32 = -65536;
pub const PSCI_1_0_FEATURES_CPU_SUSPEND_PF_SHIFT: u32 = 1;
pub const PSCI_1_0_FEATURES_CPU_SUSPEND_PF_MASK: u32 = 2;
pub const PSCI_1_0_SUSPEND_MODE_PC: u32 = 0;
pub const PSCI_1_0_SUSPEND_MODE_OSI: u32 = 1;
pub const PSCI_RET_SUCCESS: u32 = 0;
pub const PSCI_RET_NOT_SUPPORTED: i32 = -1;
pub const PSCI_RET_INVALID_PARAMS: i32 = -2;
pub const PSCI_RET_DENIED: i32 = -3;
pub const PSCI_RET_ALREADY_ON: i32 = -4;
pub const PSCI_RET_ON_PENDING: i32 = -5;
pub const PSCI_RET_INTERNAL_FAILURE: i32 = -6;
pub const PSCI_RET_NOT_PRESENT: i32 = -7;
pub const PSCI_RET_DISABLED: i32 = -8;
pub const PSCI_RET_INVALID_ADDRESS: i32 = -9;
pub const HWCAP_FP: u32 = 1;
pub const HWCAP_ASIMD: u32 = 2;
pub const HWCAP_EVTSTRM: u32 = 4;
pub const HWCAP_AES: u32 = 8;
pub const HWCAP_PMULL: u32 = 16;
pub const HWCAP_SHA1: u32 = 32;
pub const HWCAP_SHA2: u32 = 64;
pub const HWCAP_CRC32: u32 = 128;
pub const HWCAP_ATOMICS: u32 = 256;
pub const HWCAP_FPHP: u32 = 512;
pub const HWCAP_ASIMDHP: u32 = 1024;
pub const HWCAP_CPUID: u32 = 2048;
pub const HWCAP_ASIMDRDM: u32 = 4096;
pub const HWCAP_JSCVT: u32 = 8192;
pub const HWCAP_FCMA: u32 = 16384;
pub const HWCAP_LRCPC: u32 = 32768;
pub const HWCAP_DCPOP: u32 = 65536;
pub const HWCAP_SHA3: u32 = 131072;
pub const HWCAP_SM3: u32 = 262144;
pub const HWCAP_SM4: u32 = 524288;
pub const HWCAP_ASIMDDP: u32 = 1048576;
pub const HWCAP_SHA512: u32 = 2097152;
pub const HWCAP_SVE: u32 = 4194304;
pub const HWCAP_ASIMDFHM: u32 = 8388608;
pub const HWCAP_DIT: u32 = 16777216;
pub const HWCAP_USCAT: u32 = 33554432;
pub const HWCAP_ILRCPC: u32 = 67108864;
pub const HWCAP_FLAGM: u32 = 134217728;
pub const HWCAP_SSBS: u32 = 268435456;
pub const HWCAP_SB: u32 = 536870912;
pub const HWCAP_PACA: u32 = 1073741824;
pub const HWCAP_PACG: u32 = 2147483648;
pub const HWCAP2_DCPODP: u32 = 1;
pub const HWCAP2_SVE2: u32 = 2;
pub const HWCAP2_SVEAES: u32 = 4;
pub const HWCAP2_SVEPMULL: u32 = 8;
pub const HWCAP2_SVEBITPERM: u32 = 16;
pub const HWCAP2_SVESHA3: u32 = 32;
pub const HWCAP2_SVESM4: u32 = 64;
pub const HWCAP2_FLAGM2: u32 = 128;
pub const HWCAP2_FRINT: u32 = 256;
pub const HWCAP2_SVEI8MM: u32 = 512;
pub const HWCAP2_SVEF32MM: u32 = 1024;
pub const HWCAP2_SVEF64MM: u32 = 2048;
pub const HWCAP2_SVEBF16: u32 = 4096;
pub const HWCAP2_I8MM: u32 = 8192;
pub const HWCAP2_BF16: u32 = 16384;
pub const HWCAP2_DGH: u32 = 32768;
pub const HWCAP2_RNG: u32 = 65536;
pub const HWCAP2_BTI: u32 = 131072;
pub const HWCAP2_MTE: u32 = 262144;
pub const HWCAP2_ECV: u32 = 524288;
pub const HWCAP2_AFP: u32 = 1048576;
pub const HWCAP2_RPRES: u32 = 2097152;
pub const HWCAP2_MTE3: u32 = 4194304;
pub const HWCAP2_SME: u32 = 8388608;
pub const HWCAP2_SME_I16I64: u32 = 16777216;
pub const HWCAP2_SME_F64F64: u32 = 33554432;
pub const HWCAP2_SME_I8I32: u32 = 67108864;
pub const HWCAP2_SME_F16F32: u32 = 134217728;
pub const HWCAP2_SME_B16F32: u32 = 268435456;
pub const HWCAP2_SME_F32F32: u32 = 536870912;
pub const HWCAP2_SME_FA64: u32 = 1073741824;
pub const HWCAP2_WFXT: u32 = 2147483648;
pub const HWCAP2_EBF16: u64 = 4294967296;
pub const HWCAP2_SVE_EBF16: u64 = 8589934592;
pub const HWCAP2_CSSC: u64 = 17179869184;
pub const HWCAP2_RPRFM: u64 = 34359738368;
pub const HWCAP2_SVE2P1: u64 = 68719476736;
pub const HWCAP2_SME2: u64 = 137438953472;
pub const HWCAP2_SME2P1: u64 = 274877906944;
pub const HWCAP2_SME_I16I32: u64 = 549755813888;
pub const HWCAP2_SME_BI32I32: u64 = 1099511627776;
pub const HWCAP2_SME_B16B16: u64 = 2199023255552;
pub const HWCAP2_SME_F16F16: u64 = 4398046511104;
pub const HWCAP2_MOPS: u64 = 8796093022208;
pub const HWCAP2_HBC: u64 = 17592186044416;
pub const HWCAP2_SVE_B16B16: u64 = 35184372088832;
pub const HWCAP2_LRCPC3: u64 = 70368744177664;
pub const HWCAP2_LSE128: u64 = 140737488355328;
pub const HWCAP2_FPMR: u64 = 281474976710656;
pub const HWCAP2_LUT: u64 = 562949953421312;
pub const HWCAP2_FAMINMAX: u64 = 1125899906842624;
pub const HWCAP2_F8CVT: u64 = 2251799813685248;
pub const HWCAP2_F8FMA: u64 = 4503599627370496;
pub const HWCAP2_F8DP4: u64 = 9007199254740992;
pub const HWCAP2_F8DP2: u64 = 18014398509481984;
pub const HWCAP2_F8E4M3: u64 = 36028797018963968;
pub const HWCAP2_F8E5M2: u64 = 72057594037927936;
pub const HWCAP2_SME_LUTV2: u64 = 144115188075855872;
pub const HWCAP2_SME_F8F16: u64 = 288230376151711744;
pub const HWCAP2_SME_F8F32: u64 = 576460752303423488;
pub const HWCAP2_SME_SF8FMA: u64 = 1152921504606846976;
pub const HWCAP2_SME_SF8DP4: u64 = 2305843009213693952;
pub const HWCAP2_SME_SF8DP2: u64 = 4611686018427387904;
pub const __SVE_VQ_BYTES: u32 = 16;
pub const __SVE_VQ_MIN: u32 = 1;
pub const __SVE_VQ_MAX: u32 = 512;
pub const __SVE_VL_MIN: u32 = 16;
pub const __SVE_VL_MAX: u32 = 8192;
pub const __SVE_NUM_ZREGS: u32 = 32;
pub const __SVE_NUM_PREGS: u32 = 16;
pub const __SVE_ZREGS_OFFSET: u32 = 0;
pub const PSR_MODE_EL0t: u32 = 0;
pub const PSR_MODE_EL1t: u32 = 4;
pub const PSR_MODE_EL1h: u32 = 5;
pub const PSR_MODE_EL2t: u32 = 8;
pub const PSR_MODE_EL2h: u32 = 9;
pub const PSR_MODE_EL3t: u32 = 12;
pub const PSR_MODE_EL3h: u32 = 13;
pub const PSR_MODE_MASK: u32 = 15;
pub const PSR_MODE32_BIT: u32 = 16;
pub const PSR_F_BIT: u32 = 64;
pub const PSR_I_BIT: u32 = 128;
pub const PSR_A_BIT: u32 = 256;
pub const PSR_D_BIT: u32 = 512;
pub const PSR_BTYPE_MASK: u32 = 3072;
pub const PSR_SSBS_BIT: u32 = 4096;
pub const PSR_PAN_BIT: u32 = 4194304;
pub const PSR_UAO_BIT: u32 = 8388608;
pub const PSR_DIT_BIT: u32 = 16777216;
pub const PSR_TCO_BIT: u32 = 33554432;
pub const PSR_V_BIT: u32 = 268435456;
pub const PSR_C_BIT: u32 = 536870912;
pub const PSR_Z_BIT: u32 = 1073741824;
pub const PSR_N_BIT: u32 = 2147483648;
pub const PSR_BTYPE_SHIFT: u32 = 10;
pub const PSR_f: u32 = 4278190080;
pub const PSR_s: u32 = 16711680;
pub const PSR_x: u32 = 65280;
pub const PSR_c: u32 = 255;
pub const PSR_BTYPE_NONE: u32 = 0;
pub const PSR_BTYPE_JC: u32 = 1024;
pub const PSR_BTYPE_C: u32 = 2048;
pub const PSR_BTYPE_J: u32 = 3072;
pub const PTRACE_SYSEMU: u32 = 31;
pub const PTRACE_SYSEMU_SINGLESTEP: u32 = 32;
pub const PTRACE_PEEKMTETAGS: u32 = 33;
pub const PTRACE_POKEMTETAGS: u32 = 34;
pub const SVE_PT_REGS_MASK: u32 = 1;
pub const SVE_PT_REGS_FPSIMD: u32 = 0;
pub const SVE_PT_REGS_SVE: u32 = 1;
pub const SVE_PT_VL_INHERIT: u32 = 2;
pub const SVE_PT_VL_ONEXEC: u32 = 4;
pub const ZA_PT_VL_INHERIT: u32 = 2;
pub const ZA_PT_VL_ONEXEC: u32 = 4;
pub const KVM_COALESCED_MMIO_PAGE_OFFSET: u32 = 1;
pub const KVM_DIRTY_LOG_PAGE_OFFSET: u32 = 64;
pub const KVM_ARM_TARGET_AEM_V8: u32 = 0;
pub const KVM_ARM_TARGET_FOUNDATION_V8: u32 = 1;
pub const KVM_ARM_TARGET_CORTEX_A57: u32 = 2;
pub const KVM_ARM_TARGET_XGENE_POTENZA: u32 = 3;
pub const KVM_ARM_TARGET_CORTEX_A53: u32 = 4;
pub const KVM_ARM_TARGET_GENERIC_V8: u32 = 5;
pub const KVM_ARM_NUM_TARGETS: u32 = 6;
pub const KVM_ARM_DEVICE_TYPE_SHIFT: u32 = 0;
pub const KVM_ARM_DEVICE_ID_SHIFT: u32 = 16;
pub const KVM_ARM_DEVICE_VGIC_V2: u32 = 0;
pub const KVM_VGIC_V2_ADDR_TYPE_DIST: u32 = 0;
pub const KVM_VGIC_V2_ADDR_TYPE_CPU: u32 = 1;
pub const KVM_VGIC_V2_DIST_SIZE: u32 = 4096;
pub const KVM_VGIC_V2_CPU_SIZE: u32 = 8192;
pub const KVM_VGIC_V3_ADDR_TYPE_DIST: u32 = 2;
pub const KVM_VGIC_V3_ADDR_TYPE_REDIST: u32 = 3;
pub const KVM_VGIC_ITS_ADDR_TYPE: u32 = 4;
pub const KVM_VGIC_V3_ADDR_TYPE_REDIST_REGION: u32 = 5;
pub const KVM_ARM_VCPU_POWER_OFF: u32 = 0;
pub const KVM_ARM_VCPU_EL1_32BIT: u32 = 1;
pub const KVM_ARM_VCPU_PSCI_0_2: u32 = 2;
pub const KVM_ARM_VCPU_PMU_V3: u32 = 3;
pub const KVM_ARM_VCPU_SVE: u32 = 4;
pub const KVM_ARM_VCPU_PTRAUTH_ADDRESS: u32 = 5;
pub const KVM_ARM_VCPU_PTRAUTH_GENERIC: u32 = 6;
pub const KVM_ARM_VCPU_HAS_EL2: u32 = 7;
pub const KVM_ARM_MAX_DBG_REGS: u32 = 16;
pub const KVM_DEBUG_ARCH_HSR_HIGH_VALID: u32 = 1;
pub const KVM_GUESTDBG_USE_SW_BP: u32 = 65536;
pub const KVM_GUESTDBG_USE_HW: u32 = 131072;
pub const KVM_ARM_DEV_EL1_VTIMER: u32 = 1;
pub const KVM_ARM_DEV_EL1_PTIMER: u32 = 2;
pub const KVM_ARM_DEV_PMU: u32 = 4;
pub const KVM_PMU_EVENT_ALLOW: u32 = 0;
pub const KVM_PMU_EVENT_DENY: u32 = 1;
pub const KVM_ARM_TAGS_TO_GUEST: u32 = 0;
pub const KVM_ARM_TAGS_FROM_GUEST: u32 = 1;
pub const KVM_REG_ARM_COPROC_MASK: u32 = 268369920;
pub const KVM_REG_ARM_COPROC_SHIFT: u32 = 16;
pub const KVM_REG_ARM_CORE: u32 = 1048576;
pub const KVM_REG_ARM_DEMUX: u32 = 1114112;
pub const KVM_REG_ARM_DEMUX_ID_MASK: u32 = 65280;
pub const KVM_REG_ARM_DEMUX_ID_SHIFT: u32 = 8;
pub const KVM_REG_ARM_DEMUX_ID_CCSIDR: u32 = 0;
pub const KVM_REG_ARM_DEMUX_VAL_MASK: u32 = 255;
pub const KVM_REG_ARM_DEMUX_VAL_SHIFT: u32 = 0;
pub const KVM_REG_ARM64_SYSREG: u32 = 1245184;
pub const KVM_REG_ARM64_SYSREG_OP0_MASK: u32 = 49152;
pub const KVM_REG_ARM64_SYSREG_OP0_SHIFT: u32 = 14;
pub const KVM_REG_ARM64_SYSREG_OP1_MASK: u32 = 14336;
pub const KVM_REG_ARM64_SYSREG_OP1_SHIFT: u32 = 11;
pub const KVM_REG_ARM64_SYSREG_CRN_MASK: u32 = 1920;
pub const KVM_REG_ARM64_SYSREG_CRN_SHIFT: u32 = 7;
pub const KVM_REG_ARM64_SYSREG_CRM_MASK: u32 = 120;
pub const KVM_REG_ARM64_SYSREG_CRM_SHIFT: u32 = 3;
pub const KVM_REG_ARM64_SYSREG_OP2_MASK: u32 = 7;
pub const KVM_REG_ARM64_SYSREG_OP2_SHIFT: u32 = 0;
pub const KVM_REG_ARM_FW: u32 = 1310720;
pub const KVM_REG_ARM_SMCCC_ARCH_WORKAROUND_1_NOT_AVAIL: u32 = 0;
pub const KVM_REG_ARM_SMCCC_ARCH_WORKAROUND_1_AVAIL: u32 = 1;
pub const KVM_REG_ARM_SMCCC_ARCH_WORKAROUND_1_NOT_REQUIRED: u32 = 2;
pub const KVM_REG_ARM_SMCCC_ARCH_WORKAROUND_2_NOT_AVAIL: u32 = 0;
pub const KVM_REG_ARM_SMCCC_ARCH_WORKAROUND_2_UNKNOWN: u32 = 1;
pub const KVM_REG_ARM_SMCCC_ARCH_WORKAROUND_2_AVAIL: u32 = 2;
pub const KVM_REG_ARM_SMCCC_ARCH_WORKAROUND_2_NOT_REQUIRED: u32 = 3;
pub const KVM_REG_ARM_SMCCC_ARCH_WORKAROUND_2_ENABLED: u32 = 16;
pub const KVM_REG_ARM_SMCCC_ARCH_WORKAROUND_3_NOT_AVAIL: u32 = 0;
pub const KVM_REG_ARM_SMCCC_ARCH_WORKAROUND_3_AVAIL: u32 = 1;
pub const KVM_REG_ARM_SMCCC_ARCH_WORKAROUND_3_NOT_REQUIRED: u32 = 2;
pub const KVM_REG_ARM64_SVE: u32 = 1376256;
pub const KVM_REG_ARM64_SVE_ZREG_BASE: u32 = 0;
pub const KVM_REG_ARM64_SVE_PREG_BASE: u32 = 1024;
pub const KVM_REG_ARM64_SVE_FFR_BASE: u32 = 1536;
pub const KVM_ARM64_SVE_NUM_ZREGS: u32 = 32;
pub const KVM_ARM64_SVE_NUM_PREGS: u32 = 16;
pub const KVM_ARM64_SVE_MAX_SLICES: u32 = 32;
pub const KVM_ARM64_SVE_VQ_MIN: u32 = 1;
pub const KVM_ARM64_SVE_VQ_MAX: u32 = 512;
pub const KVM_ARM64_SVE_VLS_WORDS: u32 = 8;
pub const KVM_REG_ARM_FW_FEAT_BMAP: u32 = 1441792;
pub const KVM_ARM_VM_SMCCC_CTRL: u32 = 0;
pub const KVM_ARM_VM_SMCCC_FILTER: u32 = 0;
pub const KVM_DEV_ARM_VGIC_GRP_ADDR: u32 = 0;
pub const KVM_DEV_ARM_VGIC_GRP_DIST_REGS: u32 = 1;
pub const KVM_DEV_ARM_VGIC_GRP_CPU_REGS: u32 = 2;
pub const KVM_DEV_ARM_VGIC_CPUID_SHIFT: u32 = 32;
pub const KVM_DEV_ARM_VGIC_CPUID_MASK: u64 = 1095216660480;
pub const KVM_DEV_ARM_VGIC_V3_MPIDR_SHIFT: u32 = 32;
pub const KVM_DEV_ARM_VGIC_V3_MPIDR_MASK: i64 = -4294967296;
pub const KVM_DEV_ARM_VGIC_OFFSET_SHIFT: u32 = 0;
pub const KVM_DEV_ARM_VGIC_OFFSET_MASK: u32 = 4294967295;
pub const KVM_DEV_ARM_VGIC_SYSREG_INSTR_MASK: u32 = 65535;
pub const KVM_DEV_ARM_VGIC_GRP_NR_IRQS: u32 = 3;
pub const KVM_DEV_ARM_VGIC_GRP_CTRL: u32 = 4;
pub const KVM_DEV_ARM_VGIC_GRP_REDIST_REGS: u32 = 5;
pub const KVM_DEV_ARM_VGIC_GRP_CPU_SYSREGS: u32 = 6;
pub const KVM_DEV_ARM_VGIC_GRP_LEVEL_INFO: u32 = 7;
pub const KVM_DEV_ARM_VGIC_GRP_ITS_REGS: u32 = 8;
pub const KVM_DEV_ARM_VGIC_LINE_LEVEL_INFO_SHIFT: u32 = 10;
pub const KVM_DEV_ARM_VGIC_LINE_LEVEL_INFO_MASK: u32 = 4294966272;
pub const KVM_DEV_ARM_VGIC_LINE_LEVEL_INTID_MASK: u32 = 1023;
pub const VGIC_LEVEL_INFO_LINE_LEVEL: u32 = 0;
pub const KVM_DEV_ARM_VGIC_CTRL_INIT: u32 = 0;
pub const KVM_DEV_ARM_ITS_SAVE_TABLES: u32 = 1;
pub const KVM_DEV_ARM_ITS_RESTORE_TABLES: u32 = 2;
pub const KVM_DEV_ARM_VGIC_SAVE_PENDING_TABLES: u32 = 3;
pub const KVM_DEV_ARM_ITS_CTRL_RESET: u32 = 4;
pub const KVM_ARM_VCPU_PMU_V3_CTRL: u32 = 0;
pub const KVM_ARM_VCPU_PMU_V3_IRQ: u32 = 0;
pub const KVM_ARM_VCPU_PMU_V3_INIT: u32 = 1;
pub const KVM_ARM_VCPU_PMU_V3_FILTER: u32 = 2;
pub const KVM_ARM_VCPU_PMU_V3_SET_PMU: u32 = 3;
pub const KVM_ARM_VCPU_TIMER_CTRL: u32 = 1;
pub const KVM_ARM_VCPU_TIMER_IRQ_VTIMER: u32 = 0;
pub const KVM_ARM_VCPU_TIMER_IRQ_PTIMER: u32 = 1;
pub const KVM_ARM_VCPU_TIMER_IRQ_HVTIMER: u32 = 2;
pub const KVM_ARM_VCPU_TIMER_IRQ_HPTIMER: u32 = 3;
pub const KVM_ARM_VCPU_PVTIME_CTRL: u32 = 2;
pub const KVM_ARM_VCPU_PVTIME_IPA: u32 = 0;
pub const KVM_ARM_IRQ_VCPU2_SHIFT: u32 = 28;
pub const KVM_ARM_IRQ_VCPU2_MASK: u32 = 15;
pub const KVM_ARM_IRQ_TYPE_SHIFT: u32 = 24;
pub const KVM_ARM_IRQ_TYPE_MASK: u32 = 15;
pub const KVM_ARM_IRQ_VCPU_SHIFT: u32 = 16;
pub const KVM_ARM_IRQ_VCPU_MASK: u32 = 255;
pub const KVM_ARM_IRQ_NUM_SHIFT: u32 = 0;
pub const KVM_ARM_IRQ_NUM_MASK: u32 = 65535;
pub const KVM_ARM_IRQ_TYPE_CPU: u32 = 0;
pub const KVM_ARM_IRQ_TYPE_SPI: u32 = 1;
pub const KVM_ARM_IRQ_TYPE_PPI: u32 = 2;
pub const KVM_ARM_IRQ_CPU_IRQ: u32 = 0;
pub const KVM_ARM_IRQ_CPU_FIQ: u32 = 1;
pub const KVM_ARM_IRQ_GIC_MAX: u32 = 127;
pub const KVM_NR_IRQCHIPS: u32 = 1;
pub const KVM_PSCI_FN_BASE: u32 = 2512501342;
pub const KVM_PSCI_RET_SUCCESS: u32 = 0;
pub const KVM_PSCI_RET_NI: i32 = -1;
pub const KVM_PSCI_RET_INVAL: i32 = -2;
pub const KVM_PSCI_RET_DENIED: i32 = -3;
pub const KVM_SYSTEM_EVENT_RESET_FLAG_PSCI_RESET2: u32 = 1;
pub const KVM_EXIT_FAIL_ENTRY_CPU_UNSUPPORTED: u32 = 1;
pub const KVM_HYPERCALL_EXIT_SMC: u32 = 1;
pub const KVM_HYPERCALL_EXIT_16BIT: u32 = 2;
pub const KVM_ARM_FEATURE_ID_RANGE: u32 = 0;
pub const KVM_ARM_FEATURE_ID_RANGE_SIZE: u32 = 192;
pub const KVM_API_VERSION: u32 = 12;
pub const KVM_MEM_LOG_DIRTY_PAGES: u32 = 1;
pub const KVM_MEM_READONLY: u32 = 2;
pub const KVM_MEM_GUEST_MEMFD: u32 = 4;
pub const KVM_PIT_SPEAKER_DUMMY: u32 = 1;
pub const KVM_EXIT_HYPERV_SYNIC: u32 = 1;
pub const KVM_EXIT_HYPERV_HCALL: u32 = 2;
pub const KVM_EXIT_HYPERV_SYNDBG: u32 = 3;
pub const KVM_EXIT_XEN_HCALL: u32 = 1;
pub const KVM_S390_GET_SKEYS_NONE: u32 = 1;
pub const KVM_S390_SKEYS_MAX: u32 = 1048576;
pub const KVM_EXIT_UNKNOWN: u32 = 0;
pub const KVM_EXIT_EXCEPTION: u32 = 1;
pub const KVM_EXIT_IO: u32 = 2;
pub const KVM_EXIT_HYPERCALL: u32 = 3;
pub const KVM_EXIT_DEBUG: u32 = 4;
pub const KVM_EXIT_HLT: u32 = 5;
pub const KVM_EXIT_MMIO: u32 = 6;
pub const KVM_EXIT_IRQ_WINDOW_OPEN: u32 = 7;
pub const KVM_EXIT_SHUTDOWN: u32 = 8;
pub const KVM_EXIT_FAIL_ENTRY: u32 = 9;
pub const KVM_EXIT_INTR: u32 = 10;
pub const KVM_EXIT_SET_TPR: u32 = 11;
pub const KVM_EXIT_TPR_ACCESS: u32 = 12;
pub const KVM_EXIT_S390_SIEIC: u32 = 13;
pub const KVM_EXIT_S390_RESET: u32 = 14;
pub const KVM_EXIT_DCR: u32 = 15;
pub const KVM_EXIT_NMI: u32 = 16;
pub const KVM_EXIT_INTERNAL_ERROR: u32 = 17;
pub const KVM_EXIT_OSI: u32 = 18;
pub const KVM_EXIT_PAPR_HCALL: u32 = 19;
pub const KVM_EXIT_S390_UCONTROL: u32 = 20;
pub const KVM_EXIT_WATCHDOG: u32 = 21;
pub const KVM_EXIT_S390_TSCH: u32 = 22;
pub const KVM_EXIT_EPR: u32 = 23;
pub const KVM_EXIT_SYSTEM_EVENT: u32 = 24;
pub const KVM_EXIT_S390_STSI: u32 = 25;
pub const KVM_EXIT_IOAPIC_EOI: u32 = 26;
pub const KVM_EXIT_HYPERV: u32 = 27;
pub const KVM_EXIT_ARM_NISV: u32 = 28;
pub const KVM_EXIT_X86_RDMSR: u32 = 29;
pub const KVM_EXIT_X86_WRMSR: u32 = 30;
pub const KVM_EXIT_DIRTY_RING_FULL: u32 = 31;
pub const KVM_EXIT_AP_RESET_HOLD: u32 = 32;
pub const KVM_EXIT_X86_BUS_LOCK: u32 = 33;
pub const KVM_EXIT_XEN: u32 = 34;
pub const KVM_EXIT_RISCV_SBI: u32 = 35;
pub const KVM_EXIT_RISCV_CSR: u32 = 36;
pub const KVM_EXIT_NOTIFY: u32 = 37;
pub const KVM_EXIT_LOONGARCH_IOCSR: u32 = 38;
pub const KVM_EXIT_MEMORY_FAULT: u32 = 39;
pub const KVM_INTERNAL_ERROR_EMULATION: u32 = 1;
pub const KVM_INTERNAL_ERROR_SIMUL_EX: u32 = 2;
pub const KVM_INTERNAL_ERROR_DELIVERY_EV: u32 = 3;
pub const KVM_INTERNAL_ERROR_UNEXPECTED_EXIT_REASON: u32 = 4;
pub const KVM_INTERNAL_ERROR_EMULATION_FLAG_INSTRUCTION_BYTES: u32 = 1;
pub const KVM_EXIT_IO_IN: u32 = 0;
pub const KVM_EXIT_IO_OUT: u32 = 1;
pub const KVM_SYSTEM_EVENT_SHUTDOWN: u32 = 1;
pub const KVM_SYSTEM_EVENT_RESET: u32 = 2;
pub const KVM_SYSTEM_EVENT_CRASH: u32 = 3;
pub const KVM_SYSTEM_EVENT_WAKEUP: u32 = 4;
pub const KVM_SYSTEM_EVENT_SUSPEND: u32 = 5;
pub const KVM_SYSTEM_EVENT_SEV_TERM: u32 = 6;
pub const KVM_MSR_EXIT_REASON_INVAL: u32 = 1;
pub const KVM_MSR_EXIT_REASON_UNKNOWN: u32 = 2;
pub const KVM_MSR_EXIT_REASON_FILTER: u32 = 4;
pub const KVM_MSR_EXIT_REASON_VALID_MASK: u32 = 7;
pub const KVM_NOTIFY_CONTEXT_INVALID: u32 = 1;
pub const KVM_MEMORY_EXIT_FLAG_PRIVATE: u32 = 8;
pub const SYNC_REGS_SIZE_BYTES: u32 = 2048;
pub const KVM_MP_STATE_RUNNABLE: u32 = 0;
pub const KVM_MP_STATE_UNINITIALIZED: u32 = 1;
pub const KVM_MP_STATE_INIT_RECEIVED: u32 = 2;
pub const KVM_MP_STATE_HALTED: u32 = 3;
pub const KVM_MP_STATE_SIPI_RECEIVED: u32 = 4;
pub const KVM_MP_STATE_STOPPED: u32 = 5;
pub const KVM_MP_STATE_CHECK_STOP: u32 = 6;
pub const KVM_MP_STATE_OPERATING: u32 = 7;
pub const KVM_MP_STATE_LOAD: u32 = 8;
pub const KVM_MP_STATE_AP_RESET_HOLD: u32 = 9;
pub const KVM_MP_STATE_SUSPENDED: u32 = 10;
pub const KVM_GUESTDBG_ENABLE: u32 = 1;
pub const KVM_GUESTDBG_SINGLESTEP: u32 = 2;
pub const KVM_X86_DISABLE_EXITS_MWAIT: u32 = 1;
pub const KVM_X86_DISABLE_EXITS_HLT: u32 = 2;
pub const KVM_X86_DISABLE_EXITS_PAUSE: u32 = 4;
pub const KVM_X86_DISABLE_EXITS_CSTATE: u32 = 8;
pub const KVM_X86_DISABLE_VALID_EXITS: u32 = 15;
pub const KVMIO: u32 = 174;
pub const KVM_VM_S390_UCONTROL: u32 = 1;
pub const KVM_VM_PPC_HV: u32 = 1;
pub const KVM_VM_PPC_PR: u32 = 2;
pub const KVM_VM_MIPS_AUTO: u32 = 0;
pub const KVM_VM_MIPS_VZ: u32 = 1;
pub const KVM_VM_MIPS_TE: u32 = 2;
pub const KVM_S390_SIE_PAGE_OFFSET: u32 = 1;
pub const KVM_VM_TYPE_ARM_IPA_SIZE_MASK: u32 = 255;
pub const KVM_CAP_IRQCHIP: u32 = 0;
pub const KVM_CAP_HLT: u32 = 1;
pub const KVM_CAP_MMU_SHADOW_CACHE_CONTROL: u32 = 2;
pub const KVM_CAP_USER_MEMORY: u32 = 3;
pub const KVM_CAP_SET_TSS_ADDR: u32 = 4;
pub const KVM_CAP_VAPIC: u32 = 6;
pub const KVM_CAP_EXT_CPUID: u32 = 7;
pub const KVM_CAP_CLOCKSOURCE: u32 = 8;
pub const KVM_CAP_NR_VCPUS: u32 = 9;
pub const KVM_CAP_NR_MEMSLOTS: u32 = 10;
pub const KVM_CAP_PIT: u32 = 11;
pub const KVM_CAP_NOP_IO_DELAY: u32 = 12;
pub const KVM_CAP_PV_MMU: u32 = 13;
pub const KVM_CAP_MP_STATE: u32 = 14;
pub const KVM_CAP_COALESCED_MMIO: u32 = 15;
pub const KVM_CAP_SYNC_MMU: u32 = 16;
pub const KVM_CAP_IOMMU: u32 = 18;
pub const KVM_CAP_DESTROY_MEMORY_REGION_WORKS: u32 = 21;
pub const KVM_CAP_USER_NMI: u32 = 22;
pub const KVM_CAP_SET_GUEST_DEBUG: u32 = 23;
pub const KVM_CAP_IRQ_ROUTING: u32 = 25;
pub const KVM_CAP_IRQ_INJECT_STATUS: u32 = 26;
pub const KVM_CAP_ASSIGN_DEV_IRQ: u32 = 29;
pub const KVM_CAP_JOIN_MEMORY_REGIONS_WORKS: u32 = 30;
pub const KVM_CAP_IRQFD: u32 = 32;
pub const KVM_CAP_SET_BOOT_CPU_ID: u32 = 34;
pub const KVM_CAP_IOEVENTFD: u32 = 36;
pub const KVM_CAP_SET_IDENTITY_MAP_ADDR: u32 = 37;
pub const KVM_CAP_ADJUST_CLOCK: u32 = 39;
pub const KVM_CAP_INTERNAL_ERROR_DATA: u32 = 40;
pub const KVM_CAP_VCPU_EVENTS: u32 = 41;
pub const KVM_CAP_S390_PSW: u32 = 42;
pub const KVM_CAP_PPC_SEGSTATE: u32 = 43;
pub const KVM_CAP_HYPERV: u32 = 44;
pub const KVM_CAP_HYPERV_VAPIC: u32 = 45;
pub const KVM_CAP_HYPERV_SPIN: u32 = 46;
pub const KVM_CAP_PCI_SEGMENT: u32 = 47;
pub const KVM_CAP_PPC_PAIRED_SINGLES: u32 = 48;
pub const KVM_CAP_INTR_SHADOW: u32 = 49;
pub const KVM_CAP_X86_ROBUST_SINGLESTEP: u32 = 51;
pub const KVM_CAP_PPC_OSI: u32 = 52;
pub const KVM_CAP_PPC_UNSET_IRQ: u32 = 53;
pub const KVM_CAP_ENABLE_CAP: u32 = 54;
pub const KVM_CAP_PPC_GET_PVINFO: u32 = 57;
pub const KVM_CAP_PPC_IRQ_LEVEL: u32 = 58;
pub const KVM_CAP_ASYNC_PF: u32 = 59;
pub const KVM_CAP_TSC_CONTROL: u32 = 60;
pub const KVM_CAP_GET_TSC_KHZ: u32 = 61;
pub const KVM_CAP_PPC_BOOKE_SREGS: u32 = 62;
pub const KVM_CAP_SPAPR_TCE: u32 = 63;
pub const KVM_CAP_PPC_SMT: u32 = 64;
pub const KVM_CAP_PPC_RMA: u32 = 65;
pub const KVM_CAP_MAX_VCPUS: u32 = 66;
pub const KVM_CAP_PPC_HIOR: u32 = 67;
pub const KVM_CAP_PPC_PAPR: u32 = 68;
pub const KVM_CAP_SW_TLB: u32 = 69;
pub const KVM_CAP_ONE_REG: u32 = 70;
pub const KVM_CAP_S390_GMAP: u32 = 71;
pub const KVM_CAP_TSC_DEADLINE_TIMER: u32 = 72;
pub const KVM_CAP_S390_UCONTROL: u32 = 73;
pub const KVM_CAP_SYNC_REGS: u32 = 74;
pub const KVM_CAP_PCI_2_3: u32 = 75;
pub const KVM_CAP_KVMCLOCK_CTRL: u32 = 76;
pub const KVM_CAP_SIGNAL_MSI: u32 = 77;
pub const KVM_CAP_PPC_GET_SMMU_INFO: u32 = 78;
pub const KVM_CAP_S390_COW: u32 = 79;
pub const KVM_CAP_PPC_ALLOC_HTAB: u32 = 80;
pub const KVM_CAP_READONLY_MEM: u32 = 81;
pub const KVM_CAP_IRQFD_RESAMPLE: u32 = 82;
pub const KVM_CAP_PPC_BOOKE_WATCHDOG: u32 = 83;
pub const KVM_CAP_PPC_HTAB_FD: u32 = 84;
pub const KVM_CAP_S390_CSS_SUPPORT: u32 = 85;
pub const KVM_CAP_PPC_EPR: u32 = 86;
pub const KVM_CAP_ARM_PSCI: u32 = 87;
pub const KVM_CAP_ARM_SET_DEVICE_ADDR: u32 = 88;
pub const KVM_CAP_DEVICE_CTRL: u32 = 89;
pub const KVM_CAP_IRQ_MPIC: u32 = 90;
pub const KVM_CAP_PPC_RTAS: u32 = 91;
pub const KVM_CAP_IRQ_XICS: u32 = 92;
pub const KVM_CAP_ARM_EL1_32BIT: u32 = 93;
pub const KVM_CAP_SPAPR_MULTITCE: u32 = 94;
pub const KVM_CAP_EXT_EMUL_CPUID: u32 = 95;
pub const KVM_CAP_HYPERV_TIME: u32 = 96;
pub const KVM_CAP_IOAPIC_POLARITY_IGNORED: u32 = 97;
pub const KVM_CAP_ENABLE_CAP_VM: u32 = 98;
pub const KVM_CAP_S390_IRQCHIP: u32 = 99;
pub const KVM_CAP_IOEVENTFD_NO_LENGTH: u32 = 100;
pub const KVM_CAP_VM_ATTRIBUTES: u32 = 101;
pub const KVM_CAP_ARM_PSCI_0_2: u32 = 102;
pub const KVM_CAP_PPC_FIXUP_HCALL: u32 = 103;
pub const KVM_CAP_PPC_ENABLE_HCALL: u32 = 104;
pub const KVM_CAP_CHECK_EXTENSION_VM: u32 = 105;
pub const KVM_CAP_S390_USER_SIGP: u32 = 106;
pub const KVM_CAP_S390_VECTOR_REGISTERS: u32 = 107;
pub const KVM_CAP_S390_MEM_OP: u32 = 108;
pub const KVM_CAP_S390_USER_STSI: u32 = 109;
pub const KVM_CAP_S390_SKEYS: u32 = 110;
pub const KVM_CAP_MIPS_FPU: u32 = 111;
pub const KVM_CAP_MIPS_MSA: u32 = 112;
pub const KVM_CAP_S390_INJECT_IRQ: u32 = 113;
pub const KVM_CAP_S390_IRQ_STATE: u32 = 114;
pub const KVM_CAP_PPC_HWRNG: u32 = 115;
pub const KVM_CAP_DISABLE_QUIRKS: u32 = 116;
pub const KVM_CAP_X86_SMM: u32 = 117;
pub const KVM_CAP_MULTI_ADDRESS_SPACE: u32 = 118;
pub const KVM_CAP_GUEST_DEBUG_HW_BPS: u32 = 119;
pub const KVM_CAP_GUEST_DEBUG_HW_WPS: u32 = 120;
pub const KVM_CAP_SPLIT_IRQCHIP: u32 = 121;
pub const KVM_CAP_IOEVENTFD_ANY_LENGTH: u32 = 122;
pub const KVM_CAP_HYPERV_SYNIC: u32 = 123;
pub const KVM_CAP_S390_RI: u32 = 124;
pub const KVM_CAP_SPAPR_TCE_64: u32 = 125;
pub const KVM_CAP_ARM_PMU_V3: u32 = 126;
pub const KVM_CAP_VCPU_ATTRIBUTES: u32 = 127;
pub const KVM_CAP_MAX_VCPU_ID: u32 = 128;
pub const KVM_CAP_X2APIC_API: u32 = 129;
pub const KVM_CAP_S390_USER_INSTR0: u32 = 130;
pub const KVM_CAP_MSI_DEVID: u32 = 131;
pub const KVM_CAP_PPC_HTM: u32 = 132;
pub const KVM_CAP_SPAPR_RESIZE_HPT: u32 = 133;
pub const KVM_CAP_PPC_MMU_RADIX: u32 = 134;
pub const KVM_CAP_PPC_MMU_HASH_V3: u32 = 135;
pub const KVM_CAP_IMMEDIATE_EXIT: u32 = 136;
pub const KVM_CAP_MIPS_VZ: u32 = 137;
pub const KVM_CAP_MIPS_TE: u32 = 138;
pub const KVM_CAP_MIPS_64BIT: u32 = 139;
pub const KVM_CAP_S390_GS: u32 = 140;
pub const KVM_CAP_S390_AIS: u32 = 141;
pub const KVM_CAP_SPAPR_TCE_VFIO: u32 = 142;
pub const KVM_CAP_X86_DISABLE_EXITS: u32 = 143;
pub const KVM_CAP_ARM_USER_IRQ: u32 = 144;
pub const KVM_CAP_S390_CMMA_MIGRATION: u32 = 145;
pub const KVM_CAP_PPC_FWNMI: u32 = 146;
pub const KVM_CAP_PPC_SMT_POSSIBLE: u32 = 147;
pub const KVM_CAP_HYPERV_SYNIC2: u32 = 148;
pub const KVM_CAP_HYPERV_VP_INDEX: u32 = 149;
pub const KVM_CAP_S390_AIS_MIGRATION: u32 = 150;
pub const KVM_CAP_PPC_GET_CPU_CHAR: u32 = 151;
pub const KVM_CAP_S390_BPB: u32 = 152;
pub const KVM_CAP_GET_MSR_FEATURES: u32 = 153;
pub const KVM_CAP_HYPERV_EVENTFD: u32 = 154;
pub const KVM_CAP_HYPERV_TLBFLUSH: u32 = 155;
pub const KVM_CAP_S390_HPAGE_1M: u32 = 156;
pub const KVM_CAP_NESTED_STATE: u32 = 157;
pub const KVM_CAP_ARM_INJECT_SERROR_ESR: u32 = 158;
pub const KVM_CAP_MSR_PLATFORM_INFO: u32 = 159;
pub const KVM_CAP_PPC_NESTED_HV: u32 = 160;
pub const KVM_CAP_HYPERV_SEND_IPI: u32 = 161;
pub const KVM_CAP_COALESCED_PIO: u32 = 162;
pub const KVM_CAP_HYPERV_ENLIGHTENED_VMCS: u32 = 163;
pub const KVM_CAP_EXCEPTION_PAYLOAD: u32 = 164;
pub const KVM_CAP_ARM_VM_IPA_SIZE: u32 = 165;
pub const KVM_CAP_MANUAL_DIRTY_LOG_PROTECT: u32 = 166;
pub const KVM_CAP_HYPERV_CPUID: u32 = 167;
pub const KVM_CAP_MANUAL_DIRTY_LOG_PROTECT2: u32 = 168;
pub const KVM_CAP_PPC_IRQ_XIVE: u32 = 169;
pub const KVM_CAP_ARM_SVE: u32 = 170;
pub const KVM_CAP_ARM_PTRAUTH_ADDRESS: u32 = 171;
pub const KVM_CAP_ARM_PTRAUTH_GENERIC: u32 = 172;
pub const KVM_CAP_PMU_EVENT_FILTER: u32 = 173;
pub const KVM_CAP_ARM_IRQ_LINE_LAYOUT_2: u32 = 174;
pub const KVM_CAP_HYPERV_DIRECT_TLBFLUSH: u32 = 175;
pub const KVM_CAP_PPC_GUEST_DEBUG_SSTEP: u32 = 176;
pub const KVM_CAP_ARM_NISV_TO_USER: u32 = 177;
pub const KVM_CAP_ARM_INJECT_EXT_DABT: u32 = 178;
pub const KVM_CAP_S390_VCPU_RESETS: u32 = 179;
pub const KVM_CAP_S390_PROTECTED: u32 = 180;
pub const KVM_CAP_PPC_SECURE_GUEST: u32 = 181;
pub const KVM_CAP_HALT_POLL: u32 = 182;
pub const KVM_CAP_ASYNC_PF_INT: u32 = 183;
pub const KVM_CAP_LAST_CPU: u32 = 184;
pub const KVM_CAP_SMALLER_MAXPHYADDR: u32 = 185;
pub const KVM_CAP_S390_DIAG318: u32 = 186;
pub const KVM_CAP_STEAL_TIME: u32 = 187;
pub const KVM_CAP_X86_USER_SPACE_MSR: u32 = 188;
pub const KVM_CAP_X86_MSR_FILTER: u32 = 189;
pub const KVM_CAP_ENFORCE_PV_FEATURE_CPUID: u32 = 190;
pub const KVM_CAP_SYS_HYPERV_CPUID: u32 = 191;
pub const KVM_CAP_DIRTY_LOG_RING: u32 = 192;
pub const KVM_CAP_X86_BUS_LOCK_EXIT: u32 = 193;
pub const KVM_CAP_PPC_DAWR1: u32 = 194;
pub const KVM_CAP_SET_GUEST_DEBUG2: u32 = 195;
pub const KVM_CAP_SGX_ATTRIBUTE: u32 = 196;
pub const KVM_CAP_VM_COPY_ENC_CONTEXT_FROM: u32 = 197;
pub const KVM_CAP_PTP_KVM: u32 = 198;
pub const KVM_CAP_HYPERV_ENFORCE_CPUID: u32 = 199;
pub const KVM_CAP_SREGS2: u32 = 200;
pub const KVM_CAP_EXIT_HYPERCALL: u32 = 201;
pub const KVM_CAP_PPC_RPT_INVALIDATE: u32 = 202;
pub const KVM_CAP_BINARY_STATS_FD: u32 = 203;
pub const KVM_CAP_EXIT_ON_EMULATION_FAILURE: u32 = 204;
pub const KVM_CAP_ARM_MTE: u32 = 205;
pub const KVM_CAP_VM_MOVE_ENC_CONTEXT_FROM: u32 = 206;
pub const KVM_CAP_VM_GPA_BITS: u32 = 207;
pub const KVM_CAP_XSAVE2: u32 = 208;
pub const KVM_CAP_SYS_ATTRIBUTES: u32 = 209;
pub const KVM_CAP_PPC_AIL_MODE_3: u32 = 210;
pub const KVM_CAP_S390_MEM_OP_EXTENSION: u32 = 211;
pub const KVM_CAP_PMU_CAPABILITY: u32 = 212;
pub const KVM_CAP_DISABLE_QUIRKS2: u32 = 213;
pub const KVM_CAP_VM_TSC_CONTROL: u32 = 214;
pub const KVM_CAP_SYSTEM_EVENT_DATA: u32 = 215;
pub const KVM_CAP_ARM_SYSTEM_SUSPEND: u32 = 216;
pub const KVM_CAP_S390_PROTECTED_DUMP: u32 = 217;
pub const KVM_CAP_X86_TRIPLE_FAULT_EVENT: u32 = 218;
pub const KVM_CAP_X86_NOTIFY_VMEXIT: u32 = 219;
pub const KVM_CAP_VM_DISABLE_NX_HUGE_PAGES: u32 = 220;
pub const KVM_CAP_S390_ZPCI_OP: u32 = 221;
pub const KVM_CAP_S390_CPU_TOPOLOGY: u32 = 222;
pub const KVM_CAP_DIRTY_LOG_RING_ACQ_REL: u32 = 223;
pub const KVM_CAP_S390_PROTECTED_ASYNC_DISABLE: u32 = 224;
pub const KVM_CAP_DIRTY_LOG_RING_WITH_BITMAP: u32 = 225;
pub const KVM_CAP_PMU_EVENT_MASKED_EVENTS: u32 = 226;
pub const KVM_CAP_COUNTER_OFFSET: u32 = 227;
pub const KVM_CAP_ARM_EAGER_SPLIT_CHUNK_SIZE: u32 = 228;
pub const KVM_CAP_ARM_SUPPORTED_BLOCK_SIZES: u32 = 229;
pub const KVM_CAP_ARM_SUPPORTED_REG_MASK_RANGES: u32 = 230;
pub const KVM_CAP_USER_MEMORY2: u32 = 231;
pub const KVM_CAP_MEMORY_FAULT_INFO: u32 = 232;
pub const KVM_CAP_MEMORY_ATTRIBUTES: u32 = 233;
pub const KVM_CAP_GUEST_MEMFD: u32 = 234;
pub const KVM_CAP_VM_TYPES: u32 = 235;
pub const KVM_IRQ_ROUTING_IRQCHIP: u32 = 1;
pub const KVM_IRQ_ROUTING_MSI: u32 = 2;
pub const KVM_IRQ_ROUTING_S390_ADAPTER: u32 = 3;
pub const KVM_IRQ_ROUTING_HV_SINT: u32 = 4;
pub const KVM_IRQ_ROUTING_XEN_EVTCHN: u32 = 5;
pub const KVM_IRQFD_FLAG_DEASSIGN: u32 = 1;
pub const KVM_IRQFD_FLAG_RESAMPLE: u32 = 2;
pub const KVM_CLOCK_TSC_STABLE: u32 = 2;
pub const KVM_CLOCK_REALTIME: u32 = 4;
pub const KVM_CLOCK_HOST_TSC: u32 = 8;
pub const KVM_MMU_FSL_BOOKE_NOHV: u32 = 0;
pub const KVM_MMU_FSL_BOOKE_HV: u32 = 1;
pub const KVM_REG_ARCH_MASK: i64 = -72057594037927936;
pub const KVM_REG_GENERIC: u32 = 0;
pub const KVM_REG_PPC: u64 = 1152921504606846976;
pub const KVM_REG_X86: u64 = 2305843009213693952;
pub const KVM_REG_IA64: u64 = 3458764513820540928;
pub const KVM_REG_ARM: u64 = 4611686018427387904;
pub const KVM_REG_S390: u64 = 5764607523034234880;
pub const KVM_REG_ARM64: u64 = 6917529027641081856;
pub const KVM_REG_MIPS: u64 = 8070450532247928832;
pub const KVM_REG_RISCV: i64 = -9223372036854775808;
pub const KVM_REG_LOONGARCH: i64 = -8070450532247928832;
pub const KVM_REG_SIZE_SHIFT: u32 = 52;
pub const KVM_REG_SIZE_MASK: u64 = 67553994410557440;
pub const KVM_REG_SIZE_U8: u32 = 0;
pub const KVM_REG_SIZE_U16: u64 = 4503599627370496;
pub const KVM_REG_SIZE_U32: u64 = 9007199254740992;
pub const KVM_REG_SIZE_U64: u64 = 13510798882111488;
pub const KVM_REG_SIZE_U128: u64 = 18014398509481984;
pub const KVM_REG_SIZE_U256: u64 = 22517998136852480;
pub const KVM_REG_SIZE_U512: u64 = 27021597764222976;
pub const KVM_REG_SIZE_U1024: u64 = 31525197391593472;
pub const KVM_REG_SIZE_U2048: u64 = 36028797018963968;
pub const KVM_MSI_VALID_DEVID: u32 = 1;
pub const KVM_CREATE_DEVICE_TEST: u32 = 1;
pub const KVM_DEV_VFIO_FILE: u32 = 1;
pub const KVM_DEV_VFIO_FILE_ADD: u32 = 1;
pub const KVM_DEV_VFIO_FILE_DEL: u32 = 2;
pub const KVM_DEV_VFIO_GROUP: u32 = 1;
pub const KVM_DEV_VFIO_GROUP_ADD: u32 = 1;
pub const KVM_DEV_VFIO_GROUP_DEL: u32 = 2;
pub const KVM_DEV_VFIO_GROUP_SET_SPAPR_TCE: u32 = 3;
pub const KVM_S390_STORE_STATUS_NOADDR: i32 = -1;
pub const KVM_S390_STORE_STATUS_PREFIXED: i32 = -2;
pub const KVM_DIRTY_LOG_MANUAL_PROTECT_ENABLE: u32 = 1;
pub const KVM_DIRTY_LOG_INITIALLY_SET: u32 = 2;
pub const KVM_DIRTY_GFN_F_MASK: u32 = 3;
pub const KVM_BUS_LOCK_DETECTION_OFF: u32 = 1;
pub const KVM_BUS_LOCK_DETECTION_EXIT: u32 = 2;
pub const KVM_PMU_CAP_DISABLE: u32 = 1;
pub const KVM_STATS_TYPE_SHIFT: u32 = 0;
pub const KVM_STATS_TYPE_MASK: u32 = 15;
pub const KVM_STATS_TYPE_CUMULATIVE: u32 = 0;
pub const KVM_STATS_TYPE_INSTANT: u32 = 1;
pub const KVM_STATS_TYPE_PEAK: u32 = 2;
pub const KVM_STATS_TYPE_LINEAR_HIST: u32 = 3;
pub const KVM_STATS_TYPE_LOG_HIST: u32 = 4;
pub const KVM_STATS_TYPE_MAX: u32 = 4;
pub const KVM_STATS_UNIT_SHIFT: u32 = 4;
pub const KVM_STATS_UNIT_MASK: u32 = 240;
pub const KVM_STATS_UNIT_NONE: u32 = 0;
pub const KVM_STATS_UNIT_BYTES: u32 = 16;
pub const KVM_STATS_UNIT_SECONDS: u32 = 32;
pub const KVM_STATS_UNIT_CYCLES: u32 = 48;
pub const KVM_STATS_UNIT_BOOLEAN: u32 = 64;
pub const KVM_STATS_UNIT_MAX: u32 = 64;
pub const KVM_STATS_BASE_SHIFT: u32 = 8;
pub const KVM_STATS_BASE_MASK: u32 = 3840;
pub const KVM_STATS_BASE_POW10: u32 = 0;
pub const KVM_STATS_BASE_POW2: u32 = 256;
pub const KVM_STATS_BASE_MAX: u32 = 256;
pub const KVM_X86_NOTIFY_VMEXIT_ENABLED: u32 = 1;
pub const KVM_X86_NOTIFY_VMEXIT_USER: u32 = 2;
pub const KVM_MEMORY_ATTRIBUTE_PRIVATE: u32 = 8;
pub type __s8 = ::std::os::raw::c_schar;
pub type __u8 = ::std::os::raw::c_uchar;
pub type __s16 = ::std::os::raw::c_short;
pub type __u16 = ::std::os::raw::c_ushort;
pub type __s32 = ::std::os::raw::c_int;
pub type __u32 = ::std::os::raw::c_uint;
pub type __s64 = ::std::os::raw::c_longlong;
pub type __u64 = ::std::os::raw::c_ulonglong;
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct __kernel_fd_set {
    pub fds_bits: [::std::os::raw::c_ulong; 16usize],
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of __kernel_fd_set"][::std::mem::size_of::<__kernel_fd_set>() - 128usize];
    ["Alignment of __kernel_fd_set"][::std::mem::align_of::<__kernel_fd_set>() - 8usize];
    ["Offset of field: __kernel_fd_set::fds_bits"]
        [::std::mem::offset_of!(__kernel_fd_set, fds_bits) - 0usize];
};
pub type __kernel_sighandler_t =
    ::std::option::Option<unsafe extern "C" fn(arg1: ::std::os::raw::c_int)>;
pub type __kernel_key_t = ::std::os::raw::c_int;
pub type __kernel_mqd_t = ::std::os::raw::c_int;
pub type __kernel_old_uid_t = ::std::os::raw::c_ushort;
pub type __kernel_old_gid_t = ::std::os::raw::c_ushort;
pub type __kernel_long_t = ::std::os::raw::c_long;
pub type __kernel_ulong_t = ::std::os::raw::c_ulong;
pub type __kernel_ino_t = __kernel_ulong_t;
pub type __kernel_mode_t = ::std::os::raw::c_uint;
pub type __kernel_pid_t = ::std::os::raw::c_int;
pub type __kernel_ipc_pid_t = ::std::os::raw::c_int;
pub type __kernel_uid_t = ::std::os::raw::c_uint;
pub type __kernel_gid_t = ::std::os::raw::c_uint;
pub type __kernel_suseconds_t = __kernel_long_t;
pub type __kernel_daddr_t = ::std::os::raw::c_int;
pub type __kernel_uid32_t = ::std::os::raw::c_uint;
pub type __kernel_gid32_t = ::std::os::raw::c_uint;
pub type __kernel_old_dev_t = ::std::os::raw::c_uint;
pub type __kernel_size_t = __kernel_ulong_t;
pub type __kernel_ssize_t = __kernel_long_t;
pub type __kernel_ptrdiff_t = __kernel_long_t;
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct __kernel_fsid_t {
    pub val: [::std::os::raw::c_int; 2usize],
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of __kernel_fsid_t"][::std::mem::size_of::<__kernel_fsid_t>() - 8usize];
    ["Alignment of __kernel_fsid_t"][::std::mem::align_of::<__kernel_fsid_t>() - 4usize];
    ["Offset of field: __kernel_fsid_t::val"]
        [::std::mem::offset_of!(__kernel_fsid_t, val) - 0usize];
};
pub type __kernel_off_t = __kernel_long_t;
pub type __kernel_loff_t = ::std::os::raw::c_longlong;
pub type __kernel_old_time_t = __kernel_long_t;
pub type __kernel_time_t = __kernel_long_t;
pub type __kernel_time64_t = ::std::os::raw::c_longlong;
pub type __kernel_clock_t = __kernel_long_t;
pub type __kernel_timer_t = ::std::os::raw::c_int;
pub type __kernel_clockid_t = ::std::os::raw::c_int;
pub type __kernel_caddr_t = *mut ::std::os::raw::c_char;
pub type __kernel_uid16_t = ::std::os::raw::c_ushort;
pub type __kernel_gid16_t = ::std::os::raw::c_ushort;
pub type __s128 = i128;
pub type __u128 = u128;
pub type __le16 = __u16;
pub type __be16 = __u16;
pub type __le32 = __u32;
pub type __be32 = __u32;
pub type __le64 = __u64;
pub type __be64 = __u64;
pub type __sum16 = __u16;
pub type __wsum = __u32;
pub type __poll_t = ::std::os::raw::c_uint;
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
#[cfg_attr(
    feature = "serde",
    derive(zerocopy::AsBytes, zerocopy::FromBytes, zerocopy::FromZeroes)
)]
pub struct user_pt_regs {
    pub regs: [__u64; 31usize],
    pub sp: __u64,
    pub pc: __u64,
    pub pstate: __u64,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of user_pt_regs"][::std::mem::size_of::<user_pt_regs>() - 272usize];
    ["Alignment of user_pt_regs"][::std::mem::align_of::<user_pt_regs>() - 8usize];
    ["Offset of field: user_pt_regs::regs"][::std::mem::offset_of!(user_pt_regs, regs) - 0usize];
    ["Offset of field: user_pt_regs::sp"][::std::mem::offset_of!(user_pt_regs, sp) - 248usize];
    ["Offset of field: user_pt_regs::pc"][::std::mem::offset_of!(user_pt_regs, pc) - 256usize];
    ["Offset of field: user_pt_regs::pstate"]
        [::std::mem::offset_of!(user_pt_regs, pstate) - 264usize];
};
#[repr(C)]
#[repr(align(16))]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
#[cfg_attr(
    feature = "serde",
    derive(zerocopy::AsBytes, zerocopy::FromBytes, zerocopy::FromZeroes)
)]
pub struct user_fpsimd_state {
    pub vregs: [__uint128_t; 32usize],
    pub fpsr: __u32,
    pub fpcr: __u32,
    pub __reserved: [__u32; 2usize],
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of user_fpsimd_state"][::std::mem::size_of::<user_fpsimd_state>() - 528usize];
    ["Alignment of user_fpsimd_state"][::std::mem::align_of::<user_fpsimd_state>() - 16usize];
    ["Offset of field: user_fpsimd_state::vregs"]
        [::std::mem::offset_of!(user_fpsimd_state, vregs) - 0usize];
    ["Offset of field: user_fpsimd_state::fpsr"]
        [::std::mem::offset_of!(user_fpsimd_state, fpsr) - 512usize];
    ["Offset of field: user_fpsimd_state::fpcr"]
        [::std::mem::offset_of!(user_fpsimd_state, fpcr) - 516usize];
    ["Offset of field: user_fpsimd_state::__reserved"]
        [::std::mem::offset_of!(user_fpsimd_state, __reserved) - 520usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct user_hwdebug_state {
    pub dbg_info: __u32,
    pub pad: __u32,
    pub dbg_regs: [user_hwdebug_state__bindgen_ty_1; 16usize],
}
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct user_hwdebug_state__bindgen_ty_1 {
    pub addr: __u64,
    pub ctrl: __u32,
    pub pad: __u32,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of user_hwdebug_state__bindgen_ty_1"]
        [::std::mem::size_of::<user_hwdebug_state__bindgen_ty_1>() - 16usize];
    ["Alignment of user_hwdebug_state__bindgen_ty_1"]
        [::std::mem::align_of::<user_hwdebug_state__bindgen_ty_1>() - 8usize];
    ["Offset of field: user_hwdebug_state__bindgen_ty_1::addr"]
        [::std::mem::offset_of!(user_hwdebug_state__bindgen_ty_1, addr) - 0usize];
    ["Offset of field: user_hwdebug_state__bindgen_ty_1::ctrl"]
        [::std::mem::offset_of!(user_hwdebug_state__bindgen_ty_1, ctrl) - 8usize];
    ["Offset of field: user_hwdebug_state__bindgen_ty_1::pad"]
        [::std::mem::offset_of!(user_hwdebug_state__bindgen_ty_1, pad) - 12usize];
};
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of user_hwdebug_state"][::std::mem::size_of::<user_hwdebug_state>() - 264usize];
    ["Alignment of user_hwdebug_state"][::std::mem::align_of::<user_hwdebug_state>() - 8usize];
    ["Offset of field: user_hwdebug_state::dbg_info"]
        [::std::mem::offset_of!(user_hwdebug_state, dbg_info) - 0usize];
    ["Offset of field: user_hwdebug_state::pad"]
        [::std::mem::offset_of!(user_hwdebug_state, pad) - 4usize];
    ["Offset of field: user_hwdebug_state::dbg_regs"]
        [::std::mem::offset_of!(user_hwdebug_state, dbg_regs) - 8usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct user_sve_header {
    pub size: __u32,
    pub max_size: __u32,
    pub vl: __u16,
    pub max_vl: __u16,
    pub flags: __u16,
    pub __reserved: __u16,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of user_sve_header"][::std::mem::size_of::<user_sve_header>() - 16usize];
    ["Alignment of user_sve_header"][::std::mem::align_of::<user_sve_header>() - 4usize];
    ["Offset of field: user_sve_header::size"]
        [::std::mem::offset_of!(user_sve_header, size) - 0usize];
    ["Offset of field: user_sve_header::max_size"]
        [::std::mem::offset_of!(user_sve_header, max_size) - 4usize];
    ["Offset of field: user_sve_header::vl"][::std::mem::offset_of!(user_sve_header, vl) - 8usize];
    ["Offset of field: user_sve_header::max_vl"]
        [::std::mem::offset_of!(user_sve_header, max_vl) - 10usize];
    ["Offset of field: user_sve_header::flags"]
        [::std::mem::offset_of!(user_sve_header, flags) - 12usize];
    ["Offset of field: user_sve_header::__reserved"]
        [::std::mem::offset_of!(user_sve_header, __reserved) - 14usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct user_pac_mask {
    pub data_mask: __u64,
    pub insn_mask: __u64,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of user_pac_mask"][::std::mem::size_of::<user_pac_mask>() - 16usize];
    ["Alignment of user_pac_mask"][::std::mem::align_of::<user_pac_mask>() - 8usize];
    ["Offset of field: user_pac_mask::data_mask"]
        [::std::mem::offset_of!(user_pac_mask, data_mask) - 0usize];
    ["Offset of field: user_pac_mask::insn_mask"]
        [::std::mem::offset_of!(user_pac_mask, insn_mask) - 8usize];
};
#[repr(C)]
#[repr(align(16))]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct user_pac_address_keys {
    pub apiakey: __uint128_t,
    pub apibkey: __uint128_t,
    pub apdakey: __uint128_t,
    pub apdbkey: __uint128_t,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of user_pac_address_keys"][::std::mem::size_of::<user_pac_address_keys>() - 64usize];
    ["Alignment of user_pac_address_keys"]
        [::std::mem::align_of::<user_pac_address_keys>() - 16usize];
    ["Offset of field: user_pac_address_keys::apiakey"]
        [::std::mem::offset_of!(user_pac_address_keys, apiakey) - 0usize];
    ["Offset of field: user_pac_address_keys::apibkey"]
        [::std::mem::offset_of!(user_pac_address_keys, apibkey) - 16usize];
    ["Offset of field: user_pac_address_keys::apdakey"]
        [::std::mem::offset_of!(user_pac_address_keys, apdakey) - 32usize];
    ["Offset of field: user_pac_address_keys::apdbkey"]
        [::std::mem::offset_of!(user_pac_address_keys, apdbkey) - 48usize];
};
#[repr(C)]
#[repr(align(16))]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct user_pac_generic_keys {
    pub apgakey: __uint128_t,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of user_pac_generic_keys"][::std::mem::size_of::<user_pac_generic_keys>() - 16usize];
    ["Alignment of user_pac_generic_keys"]
        [::std::mem::align_of::<user_pac_generic_keys>() - 16usize];
    ["Offset of field: user_pac_generic_keys::apgakey"]
        [::std::mem::offset_of!(user_pac_generic_keys, apgakey) - 0usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct user_za_header {
    pub size: __u32,
    pub max_size: __u32,
    pub vl: __u16,
    pub max_vl: __u16,
    pub flags: __u16,
    pub __reserved: __u16,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of user_za_header"][::std::mem::size_of::<user_za_header>() - 16usize];
    ["Alignment of user_za_header"][::std::mem::align_of::<user_za_header>() - 4usize];
    ["Offset of field: user_za_header::size"]
        [::std::mem::offset_of!(user_za_header, size) - 0usize];
    ["Offset of field: user_za_header::max_size"]
        [::std::mem::offset_of!(user_za_header, max_size) - 4usize];
    ["Offset of field: user_za_header::vl"][::std::mem::offset_of!(user_za_header, vl) - 8usize];
    ["Offset of field: user_za_header::max_vl"]
        [::std::mem::offset_of!(user_za_header, max_vl) - 10usize];
    ["Offset of field: user_za_header::flags"]
        [::std::mem::offset_of!(user_za_header, flags) - 12usize];
    ["Offset of field: user_za_header::__reserved"]
        [::std::mem::offset_of!(user_za_header, __reserved) - 14usize];
};
#[repr(C)]
#[repr(align(16))]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
#[cfg_attr(
    feature = "serde",
    derive(zerocopy::AsBytes, zerocopy::FromBytes, zerocopy::FromZeroes)
)]
pub struct kvm_regs {
    pub regs: user_pt_regs,
    pub sp_el1: __u64,
    pub elr_el1: __u64,
    pub spsr: [__u64; 5usize],
    pub __bindgen_padding_0: u64,
    pub fp_regs: user_fpsimd_state,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_regs"][::std::mem::size_of::<kvm_regs>() - 864usize];
    ["Alignment of kvm_regs"][::std::mem::align_of::<kvm_regs>() - 16usize];
    ["Offset of field: kvm_regs::regs"][::std::mem::offset_of!(kvm_regs, regs) - 0usize];
    ["Offset of field: kvm_regs::sp_el1"][::std::mem::offset_of!(kvm_regs, sp_el1) - 272usize];
    ["Offset of field: kvm_regs::elr_el1"][::std::mem::offset_of!(kvm_regs, elr_el1) - 280usize];
    ["Offset of field: kvm_regs::spsr"][::std::mem::offset_of!(kvm_regs, spsr) - 288usize];
    ["Offset of field: kvm_regs::fp_regs"][::std::mem::offset_of!(kvm_regs, fp_regs) - 336usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
#[cfg_attr(
    feature = "serde",
    derive(zerocopy::AsBytes, zerocopy::FromBytes, zerocopy::FromZeroes)
)]
pub struct kvm_vcpu_init {
    pub target: __u32,
    pub features: [__u32; 7usize],
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_vcpu_init"][::std::mem::size_of::<kvm_vcpu_init>() - 32usize];
    ["Alignment of kvm_vcpu_init"][::std::mem::align_of::<kvm_vcpu_init>() - 4usize];
    ["Offset of field: kvm_vcpu_init::target"]
        [::std::mem::offset_of!(kvm_vcpu_init, target) - 0usize];
    ["Offset of field: kvm_vcpu_init::features"]
        [::std::mem::offset_of!(kvm_vcpu_init, features) - 4usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_sregs {}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_sregs"][::std::mem::size_of::<kvm_sregs>() - 0usize];
    ["Alignment of kvm_sregs"][::std::mem::align_of::<kvm_sregs>() - 1usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_fpu {}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_fpu"][::std::mem::size_of::<kvm_fpu>() - 0usize];
    ["Alignment of kvm_fpu"][::std::mem::align_of::<kvm_fpu>() - 1usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_guest_debug_arch {
    pub dbg_bcr: [__u64; 16usize],
    pub dbg_bvr: [__u64; 16usize],
    pub dbg_wcr: [__u64; 16usize],
    pub dbg_wvr: [__u64; 16usize],
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_guest_debug_arch"][::std::mem::size_of::<kvm_guest_debug_arch>() - 512usize];
    ["Alignment of kvm_guest_debug_arch"][::std::mem::align_of::<kvm_guest_debug_arch>() - 8usize];
    ["Offset of field: kvm_guest_debug_arch::dbg_bcr"]
        [::std::mem::offset_of!(kvm_guest_debug_arch, dbg_bcr) - 0usize];
    ["Offset of field: kvm_guest_debug_arch::dbg_bvr"]
        [::std::mem::offset_of!(kvm_guest_debug_arch, dbg_bvr) - 128usize];
    ["Offset of field: kvm_guest_debug_arch::dbg_wcr"]
        [::std::mem::offset_of!(kvm_guest_debug_arch, dbg_wcr) - 256usize];
    ["Offset of field: kvm_guest_debug_arch::dbg_wvr"]
        [::std::mem::offset_of!(kvm_guest_debug_arch, dbg_wvr) - 384usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_debug_exit_arch {
    pub hsr: __u32,
    pub hsr_high: __u32,
    pub far: __u64,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_debug_exit_arch"][::std::mem::size_of::<kvm_debug_exit_arch>() - 16usize];
    ["Alignment of kvm_debug_exit_arch"][::std::mem::align_of::<kvm_debug_exit_arch>() - 8usize];
    ["Offset of field: kvm_debug_exit_arch::hsr"]
        [::std::mem::offset_of!(kvm_debug_exit_arch, hsr) - 0usize];
    ["Offset of field: kvm_debug_exit_arch::hsr_high"]
        [::std::mem::offset_of!(kvm_debug_exit_arch, hsr_high) - 4usize];
    ["Offset of field: kvm_debug_exit_arch::far"]
        [::std::mem::offset_of!(kvm_debug_exit_arch, far) - 8usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_sync_regs {
    pub device_irq_level: __u64,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_sync_regs"][::std::mem::size_of::<kvm_sync_regs>() - 8usize];
    ["Alignment of kvm_sync_regs"][::std::mem::align_of::<kvm_sync_regs>() - 8usize];
    ["Offset of field: kvm_sync_regs::device_irq_level"]
        [::std::mem::offset_of!(kvm_sync_regs, device_irq_level) - 0usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_pmu_event_filter {
    pub base_event: __u16,
    pub nevents: __u16,
    pub action: __u8,
    pub pad: [__u8; 3usize],
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_pmu_event_filter"][::std::mem::size_of::<kvm_pmu_event_filter>() - 8usize];
    ["Alignment of kvm_pmu_event_filter"][::std::mem::align_of::<kvm_pmu_event_filter>() - 2usize];
    ["Offset of field: kvm_pmu_event_filter::base_event"]
        [::std::mem::offset_of!(kvm_pmu_event_filter, base_event) - 0usize];
    ["Offset of field: kvm_pmu_event_filter::nevents"]
        [::std::mem::offset_of!(kvm_pmu_event_filter, nevents) - 2usize];
    ["Offset of field: kvm_pmu_event_filter::action"]
        [::std::mem::offset_of!(kvm_pmu_event_filter, action) - 4usize];
    ["Offset of field: kvm_pmu_event_filter::pad"]
        [::std::mem::offset_of!(kvm_pmu_event_filter, pad) - 5usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_vcpu_events {
    pub exception: kvm_vcpu_events__bindgen_ty_1,
    pub reserved: [__u32; 12usize],
}
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_vcpu_events__bindgen_ty_1 {
    pub serror_pending: __u8,
    pub serror_has_esr: __u8,
    pub ext_dabt_pending: __u8,
    pub pad: [__u8; 5usize],
    pub serror_esr: __u64,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_vcpu_events__bindgen_ty_1"]
        [::std::mem::size_of::<kvm_vcpu_events__bindgen_ty_1>() - 16usize];
    ["Alignment of kvm_vcpu_events__bindgen_ty_1"]
        [::std::mem::align_of::<kvm_vcpu_events__bindgen_ty_1>() - 8usize];
    ["Offset of field: kvm_vcpu_events__bindgen_ty_1::serror_pending"]
        [::std::mem::offset_of!(kvm_vcpu_events__bindgen_ty_1, serror_pending) - 0usize];
    ["Offset of field: kvm_vcpu_events__bindgen_ty_1::serror_has_esr"]
        [::std::mem::offset_of!(kvm_vcpu_events__bindgen_ty_1, serror_has_esr) - 1usize];
    ["Offset of field: kvm_vcpu_events__bindgen_ty_1::ext_dabt_pending"]
        [::std::mem::offset_of!(kvm_vcpu_events__bindgen_ty_1, ext_dabt_pending) - 2usize];
    ["Offset of field: kvm_vcpu_events__bindgen_ty_1::pad"]
        [::std::mem::offset_of!(kvm_vcpu_events__bindgen_ty_1, pad) - 3usize];
    ["Offset of field: kvm_vcpu_events__bindgen_ty_1::serror_esr"]
        [::std::mem::offset_of!(kvm_vcpu_events__bindgen_ty_1, serror_esr) - 8usize];
};
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_vcpu_events"][::std::mem::size_of::<kvm_vcpu_events>() - 64usize];
    ["Alignment of kvm_vcpu_events"][::std::mem::align_of::<kvm_vcpu_events>() - 8usize];
    ["Offset of field: kvm_vcpu_events::exception"]
        [::std::mem::offset_of!(kvm_vcpu_events, exception) - 0usize];
    ["Offset of field: kvm_vcpu_events::reserved"]
        [::std::mem::offset_of!(kvm_vcpu_events, reserved) - 16usize];
};
#[repr(C)]
#[derive(Debug, Copy, Clone, PartialEq)]
pub struct kvm_arm_copy_mte_tags {
    pub guest_ipa: __u64,
    pub length: __u64,
    pub addr: *mut ::std::os::raw::c_void,
    pub flags: __u64,
    pub reserved: [__u64; 2usize],
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_arm_copy_mte_tags"][::std::mem::size_of::<kvm_arm_copy_mte_tags>() - 48usize];
    ["Alignment of kvm_arm_copy_mte_tags"]
        [::std::mem::align_of::<kvm_arm_copy_mte_tags>() - 8usize];
    ["Offset of field: kvm_arm_copy_mte_tags::guest_ipa"]
        [::std::mem::offset_of!(kvm_arm_copy_mte_tags, guest_ipa) - 0usize];
    ["Offset of field: kvm_arm_copy_mte_tags::length"]
        [::std::mem::offset_of!(kvm_arm_copy_mte_tags, length) - 8usize];
    ["Offset of field: kvm_arm_copy_mte_tags::addr"]
        [::std::mem::offset_of!(kvm_arm_copy_mte_tags, addr) - 16usize];
    ["Offset of field: kvm_arm_copy_mte_tags::flags"]
        [::std::mem::offset_of!(kvm_arm_copy_mte_tags, flags) - 24usize];
    ["Offset of field: kvm_arm_copy_mte_tags::reserved"]
        [::std::mem::offset_of!(kvm_arm_copy_mte_tags, reserved) - 32usize];
};
impl Default for kvm_arm_copy_mte_tags {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_arm_counter_offset {
    pub counter_offset: __u64,
    pub reserved: __u64,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_arm_counter_offset"][::std::mem::size_of::<kvm_arm_counter_offset>() - 16usize];
    ["Alignment of kvm_arm_counter_offset"]
        [::std::mem::align_of::<kvm_arm_counter_offset>() - 8usize];
    ["Offset of field: kvm_arm_counter_offset::counter_offset"]
        [::std::mem::offset_of!(kvm_arm_counter_offset, counter_offset) - 0usize];
    ["Offset of field: kvm_arm_counter_offset::reserved"]
        [::std::mem::offset_of!(kvm_arm_counter_offset, reserved) - 8usize];
};
pub const KVM_REG_ARM_STD_BIT_TRNG_V1_0: _bindgen_ty_1 = 0;
pub type _bindgen_ty_1 = ::std::os::raw::c_uint;
pub const KVM_REG_ARM_STD_HYP_BIT_PV_TIME: _bindgen_ty_2 = 0;
pub type _bindgen_ty_2 = ::std::os::raw::c_uint;
pub const KVM_REG_ARM_VENDOR_HYP_BIT_FUNC_FEAT: _bindgen_ty_3 = 0;
pub const KVM_REG_ARM_VENDOR_HYP_BIT_PTP: _bindgen_ty_3 = 1;
pub type _bindgen_ty_3 = ::std::os::raw::c_uint;
pub const kvm_smccc_filter_action_KVM_SMCCC_FILTER_HANDLE: kvm_smccc_filter_action = 0;
pub const kvm_smccc_filter_action_KVM_SMCCC_FILTER_DENY: kvm_smccc_filter_action = 1;
pub const kvm_smccc_filter_action_KVM_SMCCC_FILTER_FWD_TO_USER: kvm_smccc_filter_action = 2;
pub type kvm_smccc_filter_action = ::std::os::raw::c_uint;
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_smccc_filter {
    pub base: __u32,
    pub nr_functions: __u32,
    pub action: __u8,
    pub pad: [__u8; 15usize],
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_smccc_filter"][::std::mem::size_of::<kvm_smccc_filter>() - 24usize];
    ["Alignment of kvm_smccc_filter"][::std::mem::align_of::<kvm_smccc_filter>() - 4usize];
    ["Offset of field: kvm_smccc_filter::base"]
        [::std::mem::offset_of!(kvm_smccc_filter, base) - 0usize];
    ["Offset of field: kvm_smccc_filter::nr_functions"]
        [::std::mem::offset_of!(kvm_smccc_filter, nr_functions) - 4usize];
    ["Offset of field: kvm_smccc_filter::action"]
        [::std::mem::offset_of!(kvm_smccc_filter, action) - 8usize];
    ["Offset of field: kvm_smccc_filter::pad"]
        [::std::mem::offset_of!(kvm_smccc_filter, pad) - 9usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct reg_mask_range {
    pub addr: __u64,
    pub range: __u32,
    pub reserved: [__u32; 13usize],
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of reg_mask_range"][::std::mem::size_of::<reg_mask_range>() - 64usize];
    ["Alignment of reg_mask_range"][::std::mem::align_of::<reg_mask_range>() - 8usize];
    ["Offset of field: reg_mask_range::addr"]
        [::std::mem::offset_of!(reg_mask_range, addr) - 0usize];
    ["Offset of field: reg_mask_range::range"]
        [::std::mem::offset_of!(reg_mask_range, range) - 8usize];
    ["Offset of field: reg_mask_range::reserved"]
        [::std::mem::offset_of!(reg_mask_range, reserved) - 12usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_userspace_memory_region {
    pub slot: __u32,
    pub flags: __u32,
    pub guest_phys_addr: __u64,
    pub memory_size: __u64,
    pub userspace_addr: __u64,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_userspace_memory_region"]
        [::std::mem::size_of::<kvm_userspace_memory_region>() - 32usize];
    ["Alignment of kvm_userspace_memory_region"]
        [::std::mem::align_of::<kvm_userspace_memory_region>() - 8usize];
    ["Offset of field: kvm_userspace_memory_region::slot"]
        [::std::mem::offset_of!(kvm_userspace_memory_region, slot) - 0usize];
    ["Offset of field: kvm_userspace_memory_region::flags"]
        [::std::mem::offset_of!(kvm_userspace_memory_region, flags) - 4usize];
    ["Offset of field: kvm_userspace_memory_region::guest_phys_addr"]
        [::std::mem::offset_of!(kvm_userspace_memory_region, guest_phys_addr) - 8usize];
    ["Offset of field: kvm_userspace_memory_region::memory_size"]
        [::std::mem::offset_of!(kvm_userspace_memory_region, memory_size) - 16usize];
    ["Offset of field: kvm_userspace_memory_region::userspace_addr"]
        [::std::mem::offset_of!(kvm_userspace_memory_region, userspace_addr) - 24usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_userspace_memory_region2 {
    pub slot: __u32,
    pub flags: __u32,
    pub guest_phys_addr: __u64,
    pub memory_size: __u64,
    pub userspace_addr: __u64,
    pub guest_memfd_offset: __u64,
    pub guest_memfd: __u32,
    pub pad1: __u32,
    pub pad2: [__u64; 14usize],
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_userspace_memory_region2"]
        [::std::mem::size_of::<kvm_userspace_memory_region2>() - 160usize];
    ["Alignment of kvm_userspace_memory_region2"]
        [::std::mem::align_of::<kvm_userspace_memory_region2>() - 8usize];
    ["Offset of field: kvm_userspace_memory_region2::slot"]
        [::std::mem::offset_of!(kvm_userspace_memory_region2, slot) - 0usize];
    ["Offset of field: kvm_userspace_memory_region2::flags"]
        [::std::mem::offset_of!(kvm_userspace_memory_region2, flags) - 4usize];
    ["Offset of field: kvm_userspace_memory_region2::guest_phys_addr"]
        [::std::mem::offset_of!(kvm_userspace_memory_region2, guest_phys_addr) - 8usize];
    ["Offset of field: kvm_userspace_memory_region2::memory_size"]
        [::std::mem::offset_of!(kvm_userspace_memory_region2, memory_size) - 16usize];
    ["Offset of field: kvm_userspace_memory_region2::userspace_addr"]
        [::std::mem::offset_of!(kvm_userspace_memory_region2, userspace_addr) - 24usize];
    ["Offset of field: kvm_userspace_memory_region2::guest_memfd_offset"]
        [::std::mem::offset_of!(kvm_userspace_memory_region2, guest_memfd_offset) - 32usize];
    ["Offset of field: kvm_userspace_memory_region2::guest_memfd"]
        [::std::mem::offset_of!(kvm_userspace_memory_region2, guest_memfd) - 40usize];
    ["Offset of field: kvm_userspace_memory_region2::pad1"]
        [::std::mem::offset_of!(kvm_userspace_memory_region2, pad1) - 44usize];
    ["Offset of field: kvm_userspace_memory_region2::pad2"]
        [::std::mem::offset_of!(kvm_userspace_memory_region2, pad2) - 48usize];
};
#[repr(C)]
#[derive(Copy, Clone)]
pub struct kvm_irq_level {
    pub __bindgen_anon_1: kvm_irq_level__bindgen_ty_1,
    pub level: __u32,
}
#[repr(C)]
#[derive(Copy, Clone)]
pub union kvm_irq_level__bindgen_ty_1 {
    pub irq: __u32,
    pub status: __s32,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_irq_level__bindgen_ty_1"]
        [::std::mem::size_of::<kvm_irq_level__bindgen_ty_1>() - 4usize];
    ["Alignment of kvm_irq_level__bindgen_ty_1"]
        [::std::mem::align_of::<kvm_irq_level__bindgen_ty_1>() - 4usize];
    ["Offset of field: kvm_irq_level__bindgen_ty_1::irq"]
        [::std::mem::offset_of!(kvm_irq_level__bindgen_ty_1, irq) - 0usize];
    ["Offset of field: kvm_irq_level__bindgen_ty_1::status"]
        [::std::mem::offset_of!(kvm_irq_level__bindgen_ty_1, status) - 0usize];
};
impl Default for kvm_irq_level__bindgen_ty_1 {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_irq_level__bindgen_ty_1 {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write!(f, "kvm_irq_level__bindgen_ty_1 {{ union }}")
    }
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_irq_level"][::std::mem::size_of::<kvm_irq_level>() - 8usize];
    ["Alignment of kvm_irq_level"][::std::mem::align_of::<kvm_irq_level>() - 4usize];
    ["Offset of field: kvm_irq_level::level"]
        [::std::mem::offset_of!(kvm_irq_level, level) - 4usize];
};
impl Default for kvm_irq_level {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_irq_level {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write!(
            f,
            "kvm_irq_level {{ __bindgen_anon_1: {:?}, level: {:?} }}",
            self.__bindgen_anon_1, self.level
        )
    }
}
#[repr(C)]
#[derive(Copy, Clone)]
pub struct kvm_irqchip {
    pub chip_id: __u32,
    pub pad: __u32,
    pub chip: kvm_irqchip__bindgen_ty_1,
}
#[repr(C)]
#[derive(Copy, Clone)]
pub union kvm_irqchip__bindgen_ty_1 {
    pub dummy: [::std::os::raw::c_char; 512usize],
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_irqchip__bindgen_ty_1"]
        [::std::mem::size_of::<kvm_irqchip__bindgen_ty_1>() - 512usize];
    ["Alignment of kvm_irqchip__bindgen_ty_1"]
        [::std::mem::align_of::<kvm_irqchip__bindgen_ty_1>() - 1usize];
    ["Offset of field: kvm_irqchip__bindgen_ty_1::dummy"]
        [::std::mem::offset_of!(kvm_irqchip__bindgen_ty_1, dummy) - 0usize];
};
impl Default for kvm_irqchip__bindgen_ty_1 {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_irqchip__bindgen_ty_1 {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write!(f, "kvm_irqchip__bindgen_ty_1 {{ union }}")
    }
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_irqchip"][::std::mem::size_of::<kvm_irqchip>() - 520usize];
    ["Alignment of kvm_irqchip"][::std::mem::align_of::<kvm_irqchip>() - 4usize];
    ["Offset of field: kvm_irqchip::chip_id"]
        [::std::mem::offset_of!(kvm_irqchip, chip_id) - 0usize];
    ["Offset of field: kvm_irqchip::pad"][::std::mem::offset_of!(kvm_irqchip, pad) - 4usize];
    ["Offset of field: kvm_irqchip::chip"][::std::mem::offset_of!(kvm_irqchip, chip) - 8usize];
};
impl Default for kvm_irqchip {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_irqchip {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write!(
            f,
            "kvm_irqchip {{ chip_id: {:?}, pad: {:?}, chip: {:?} }}",
            self.chip_id, self.pad, self.chip
        )
    }
}
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_pit_config {
    pub flags: __u32,
    pub pad: [__u32; 15usize],
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_pit_config"][::std::mem::size_of::<kvm_pit_config>() - 64usize];
    ["Alignment of kvm_pit_config"][::std::mem::align_of::<kvm_pit_config>() - 4usize];
    ["Offset of field: kvm_pit_config::flags"]
        [::std::mem::offset_of!(kvm_pit_config, flags) - 0usize];
    ["Offset of field: kvm_pit_config::pad"][::std::mem::offset_of!(kvm_pit_config, pad) - 4usize];
};
#[repr(C)]
#[derive(Copy, Clone)]
pub struct kvm_hyperv_exit {
    pub type_: __u32,
    pub pad1: __u32,
    pub u: kvm_hyperv_exit__bindgen_ty_1,
}
#[repr(C)]
#[derive(Copy, Clone)]
pub union kvm_hyperv_exit__bindgen_ty_1 {
    pub synic: kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_1,
    pub hcall: kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_2,
    pub syndbg: kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_3,
}
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_1 {
    pub msr: __u32,
    pub pad2: __u32,
    pub control: __u64,
    pub evt_page: __u64,
    pub msg_page: __u64,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_1"]
        [::std::mem::size_of::<kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_1>() - 32usize];
    ["Alignment of kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_1"]
        [::std::mem::align_of::<kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_1>() - 8usize];
    ["Offset of field: kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_1::msr"]
        [::std::mem::offset_of!(kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_1, msr) - 0usize];
    ["Offset of field: kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_1::pad2"]
        [::std::mem::offset_of!(kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_1, pad2) - 4usize];
    ["Offset of field: kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_1::control"]
        [::std::mem::offset_of!(kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_1, control) - 8usize];
    ["Offset of field: kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_1::evt_page"]
        [::std::mem::offset_of!(kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_1, evt_page) - 16usize];
    ["Offset of field: kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_1::msg_page"]
        [::std::mem::offset_of!(kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_1, msg_page) - 24usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_2 {
    pub input: __u64,
    pub result: __u64,
    pub params: [__u64; 2usize],
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_2"]
        [::std::mem::size_of::<kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_2>() - 32usize];
    ["Alignment of kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_2"]
        [::std::mem::align_of::<kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_2>() - 8usize];
    ["Offset of field: kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_2::input"]
        [::std::mem::offset_of!(kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_2, input) - 0usize];
    ["Offset of field: kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_2::result"]
        [::std::mem::offset_of!(kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_2, result) - 8usize];
    ["Offset of field: kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_2::params"]
        [::std::mem::offset_of!(kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_2, params) - 16usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_3 {
    pub msr: __u32,
    pub pad2: __u32,
    pub control: __u64,
    pub status: __u64,
    pub send_page: __u64,
    pub recv_page: __u64,
    pub pending_page: __u64,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_3"]
        [::std::mem::size_of::<kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_3>() - 48usize];
    ["Alignment of kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_3"]
        [::std::mem::align_of::<kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_3>() - 8usize];
    ["Offset of field: kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_3::msr"]
        [::std::mem::offset_of!(kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_3, msr) - 0usize];
    ["Offset of field: kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_3::pad2"]
        [::std::mem::offset_of!(kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_3, pad2) - 4usize];
    ["Offset of field: kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_3::control"]
        [::std::mem::offset_of!(kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_3, control) - 8usize];
    ["Offset of field: kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_3::status"]
        [::std::mem::offset_of!(kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_3, status) - 16usize];
    ["Offset of field: kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_3::send_page"]
        [::std::mem::offset_of!(kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_3, send_page) - 24usize];
    ["Offset of field: kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_3::recv_page"]
        [::std::mem::offset_of!(kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_3, recv_page) - 32usize];
    ["Offset of field: kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_3::pending_page"][::std::mem::offset_of!(
        kvm_hyperv_exit__bindgen_ty_1__bindgen_ty_3,
        pending_page
    ) - 40usize];
};
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_hyperv_exit__bindgen_ty_1"]
        [::std::mem::size_of::<kvm_hyperv_exit__bindgen_ty_1>() - 48usize];
    ["Alignment of kvm_hyperv_exit__bindgen_ty_1"]
        [::std::mem::align_of::<kvm_hyperv_exit__bindgen_ty_1>() - 8usize];
    ["Offset of field: kvm_hyperv_exit__bindgen_ty_1::synic"]
        [::std::mem::offset_of!(kvm_hyperv_exit__bindgen_ty_1, synic) - 0usize];
    ["Offset of field: kvm_hyperv_exit__bindgen_ty_1::hcall"]
        [::std::mem::offset_of!(kvm_hyperv_exit__bindgen_ty_1, hcall) - 0usize];
    ["Offset of field: kvm_hyperv_exit__bindgen_ty_1::syndbg"]
        [::std::mem::offset_of!(kvm_hyperv_exit__bindgen_ty_1, syndbg) - 0usize];
};
impl Default for kvm_hyperv_exit__bindgen_ty_1 {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_hyperv_exit__bindgen_ty_1 {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write!(f, "kvm_hyperv_exit__bindgen_ty_1 {{ union }}")
    }
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_hyperv_exit"][::std::mem::size_of::<kvm_hyperv_exit>() - 56usize];
    ["Alignment of kvm_hyperv_exit"][::std::mem::align_of::<kvm_hyperv_exit>() - 8usize];
    ["Offset of field: kvm_hyperv_exit::type_"]
        [::std::mem::offset_of!(kvm_hyperv_exit, type_) - 0usize];
    ["Offset of field: kvm_hyperv_exit::pad1"]
        [::std::mem::offset_of!(kvm_hyperv_exit, pad1) - 4usize];
    ["Offset of field: kvm_hyperv_exit::u"][::std::mem::offset_of!(kvm_hyperv_exit, u) - 8usize];
};
impl Default for kvm_hyperv_exit {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_hyperv_exit {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write!(
            f,
            "kvm_hyperv_exit {{ type: {:?}, pad1: {:?}, u: {:?} }}",
            self.type_, self.pad1, self.u
        )
    }
}
#[repr(C)]
#[derive(Copy, Clone)]
pub struct kvm_xen_exit {
    pub type_: __u32,
    pub u: kvm_xen_exit__bindgen_ty_1,
}
#[repr(C)]
#[derive(Copy, Clone)]
pub union kvm_xen_exit__bindgen_ty_1 {
    pub hcall: kvm_xen_exit__bindgen_ty_1__bindgen_ty_1,
}
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_xen_exit__bindgen_ty_1__bindgen_ty_1 {
    pub longmode: __u32,
    pub cpl: __u32,
    pub input: __u64,
    pub result: __u64,
    pub params: [__u64; 6usize],
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_xen_exit__bindgen_ty_1__bindgen_ty_1"]
        [::std::mem::size_of::<kvm_xen_exit__bindgen_ty_1__bindgen_ty_1>() - 72usize];
    ["Alignment of kvm_xen_exit__bindgen_ty_1__bindgen_ty_1"]
        [::std::mem::align_of::<kvm_xen_exit__bindgen_ty_1__bindgen_ty_1>() - 8usize];
    ["Offset of field: kvm_xen_exit__bindgen_ty_1__bindgen_ty_1::longmode"]
        [::std::mem::offset_of!(kvm_xen_exit__bindgen_ty_1__bindgen_ty_1, longmode) - 0usize];
    ["Offset of field: kvm_xen_exit__bindgen_ty_1__bindgen_ty_1::cpl"]
        [::std::mem::offset_of!(kvm_xen_exit__bindgen_ty_1__bindgen_ty_1, cpl) - 4usize];
    ["Offset of field: kvm_xen_exit__bindgen_ty_1__bindgen_ty_1::input"]
        [::std::mem::offset_of!(kvm_xen_exit__bindgen_ty_1__bindgen_ty_1, input) - 8usize];
    ["Offset of field: kvm_xen_exit__bindgen_ty_1__bindgen_ty_1::result"]
        [::std::mem::offset_of!(kvm_xen_exit__bindgen_ty_1__bindgen_ty_1, result) - 16usize];
    ["Offset of field: kvm_xen_exit__bindgen_ty_1__bindgen_ty_1::params"]
        [::std::mem::offset_of!(kvm_xen_exit__bindgen_ty_1__bindgen_ty_1, params) - 24usize];
};
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_xen_exit__bindgen_ty_1"]
        [::std::mem::size_of::<kvm_xen_exit__bindgen_ty_1>() - 72usize];
    ["Alignment of kvm_xen_exit__bindgen_ty_1"]
        [::std::mem::align_of::<kvm_xen_exit__bindgen_ty_1>() - 8usize];
    ["Offset of field: kvm_xen_exit__bindgen_ty_1::hcall"]
        [::std::mem::offset_of!(kvm_xen_exit__bindgen_ty_1, hcall) - 0usize];
};
impl Default for kvm_xen_exit__bindgen_ty_1 {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_xen_exit__bindgen_ty_1 {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write!(f, "kvm_xen_exit__bindgen_ty_1 {{ union }}")
    }
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_xen_exit"][::std::mem::size_of::<kvm_xen_exit>() - 80usize];
    ["Alignment of kvm_xen_exit"][::std::mem::align_of::<kvm_xen_exit>() - 8usize];
    ["Offset of field: kvm_xen_exit::type_"][::std::mem::offset_of!(kvm_xen_exit, type_) - 0usize];
    ["Offset of field: kvm_xen_exit::u"][::std::mem::offset_of!(kvm_xen_exit, u) - 8usize];
};
impl Default for kvm_xen_exit {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_xen_exit {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write!(
            f,
            "kvm_xen_exit {{ type: {:?}, u: {:?} }}",
            self.type_, self.u
        )
    }
}
#[repr(C)]
#[derive(Copy, Clone)]
pub struct kvm_run {
    pub request_interrupt_window: __u8,
    pub immediate_exit: __u8,
    pub padding1: [__u8; 6usize],
    pub exit_reason: __u32,
    pub ready_for_interrupt_injection: __u8,
    pub if_flag: __u8,
    pub flags: __u16,
    pub cr8: __u64,
    pub apic_base: __u64,
    pub __bindgen_anon_1: kvm_run__bindgen_ty_1,
    pub kvm_valid_regs: __u64,
    pub kvm_dirty_regs: __u64,
    pub s: kvm_run__bindgen_ty_2,
}
#[repr(C)]
#[derive(Copy, Clone)]
pub union kvm_run__bindgen_ty_1 {
    pub hw: kvm_run__bindgen_ty_1__bindgen_ty_1,
    pub fail_entry: kvm_run__bindgen_ty_1__bindgen_ty_2,
    pub ex: kvm_run__bindgen_ty_1__bindgen_ty_3,
    pub io: kvm_run__bindgen_ty_1__bindgen_ty_4,
    pub debug: kvm_run__bindgen_ty_1__bindgen_ty_5,
    pub mmio: kvm_run__bindgen_ty_1__bindgen_ty_6,
    pub iocsr_io: kvm_run__bindgen_ty_1__bindgen_ty_7,
    pub hypercall: kvm_run__bindgen_ty_1__bindgen_ty_8,
    pub tpr_access: kvm_run__bindgen_ty_1__bindgen_ty_9,
    pub s390_sieic: kvm_run__bindgen_ty_1__bindgen_ty_10,
    pub s390_reset_flags: __u64,
    pub s390_ucontrol: kvm_run__bindgen_ty_1__bindgen_ty_11,
    pub dcr: kvm_run__bindgen_ty_1__bindgen_ty_12,
    pub internal: kvm_run__bindgen_ty_1__bindgen_ty_13,
    pub emulation_failure: kvm_run__bindgen_ty_1__bindgen_ty_14,
    pub osi: kvm_run__bindgen_ty_1__bindgen_ty_15,
    pub papr_hcall: kvm_run__bindgen_ty_1__bindgen_ty_16,
    pub s390_tsch: kvm_run__bindgen_ty_1__bindgen_ty_17,
    pub epr: kvm_run__bindgen_ty_1__bindgen_ty_18,
    pub system_event: kvm_run__bindgen_ty_1__bindgen_ty_19,
    pub s390_stsi: kvm_run__bindgen_ty_1__bindgen_ty_20,
    pub eoi: kvm_run__bindgen_ty_1__bindgen_ty_21,
    pub hyperv: kvm_hyperv_exit,
    pub arm_nisv: kvm_run__bindgen_ty_1__bindgen_ty_22,
    pub msr: kvm_run__bindgen_ty_1__bindgen_ty_23,
    pub xen: kvm_xen_exit,
    pub riscv_sbi: kvm_run__bindgen_ty_1__bindgen_ty_24,
    pub riscv_csr: kvm_run__bindgen_ty_1__bindgen_ty_25,
    pub notify: kvm_run__bindgen_ty_1__bindgen_ty_26,
    pub memory_fault: kvm_run__bindgen_ty_1__bindgen_ty_27,
    pub padding: [::std::os::raw::c_char; 256usize],
}
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_run__bindgen_ty_1__bindgen_ty_1 {
    pub hardware_exit_reason: __u64,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_1"]
        [::std::mem::size_of::<kvm_run__bindgen_ty_1__bindgen_ty_1>() - 8usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_1"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_1>() - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_1::hardware_exit_reason"][::std::mem::offset_of!(
        kvm_run__bindgen_ty_1__bindgen_ty_1,
        hardware_exit_reason
    ) - 0usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_run__bindgen_ty_1__bindgen_ty_2 {
    pub hardware_entry_failure_reason: __u64,
    pub cpu: __u32,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_2"]
        [::std::mem::size_of::<kvm_run__bindgen_ty_1__bindgen_ty_2>() - 16usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_2"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_2>() - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_2::hardware_entry_failure_reason"][::std::mem::offset_of!(
        kvm_run__bindgen_ty_1__bindgen_ty_2,
        hardware_entry_failure_reason
    )
        - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_2::cpu"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_2, cpu) - 8usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_run__bindgen_ty_1__bindgen_ty_3 {
    pub exception: __u32,
    pub error_code: __u32,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_3"]
        [::std::mem::size_of::<kvm_run__bindgen_ty_1__bindgen_ty_3>() - 8usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_3"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_3>() - 4usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_3::exception"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_3, exception) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_3::error_code"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_3, error_code) - 4usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_run__bindgen_ty_1__bindgen_ty_4 {
    pub direction: __u8,
    pub size: __u8,
    pub port: __u16,
    pub count: __u32,
    pub data_offset: __u64,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_4"]
        [::std::mem::size_of::<kvm_run__bindgen_ty_1__bindgen_ty_4>() - 16usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_4"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_4>() - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_4::direction"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_4, direction) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_4::size"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_4, size) - 1usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_4::port"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_4, port) - 2usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_4::count"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_4, count) - 4usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_4::data_offset"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_4, data_offset) - 8usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_run__bindgen_ty_1__bindgen_ty_5 {
    pub arch: kvm_debug_exit_arch,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_5"]
        [::std::mem::size_of::<kvm_run__bindgen_ty_1__bindgen_ty_5>() - 16usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_5"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_5>() - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_5::arch"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_5, arch) - 0usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_run__bindgen_ty_1__bindgen_ty_6 {
    pub phys_addr: __u64,
    pub data: [__u8; 8usize],
    pub len: __u32,
    pub is_write: __u8,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_6"]
        [::std::mem::size_of::<kvm_run__bindgen_ty_1__bindgen_ty_6>() - 24usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_6"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_6>() - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_6::phys_addr"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_6, phys_addr) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_6::data"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_6, data) - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_6::len"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_6, len) - 16usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_6::is_write"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_6, is_write) - 20usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_run__bindgen_ty_1__bindgen_ty_7 {
    pub phys_addr: __u64,
    pub data: [__u8; 8usize],
    pub len: __u32,
    pub is_write: __u8,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_7"]
        [::std::mem::size_of::<kvm_run__bindgen_ty_1__bindgen_ty_7>() - 24usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_7"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_7>() - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_7::phys_addr"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_7, phys_addr) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_7::data"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_7, data) - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_7::len"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_7, len) - 16usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_7::is_write"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_7, is_write) - 20usize];
};
#[repr(C)]
#[derive(Copy, Clone)]
pub struct kvm_run__bindgen_ty_1__bindgen_ty_8 {
    pub nr: __u64,
    pub args: [__u64; 6usize],
    pub ret: __u64,
    pub __bindgen_anon_1: kvm_run__bindgen_ty_1__bindgen_ty_8__bindgen_ty_1,
}
#[repr(C)]
#[derive(Copy, Clone)]
pub union kvm_run__bindgen_ty_1__bindgen_ty_8__bindgen_ty_1 {
    pub longmode: __u32,
    pub flags: __u64,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_8__bindgen_ty_1"]
        [::std::mem::size_of::<kvm_run__bindgen_ty_1__bindgen_ty_8__bindgen_ty_1>() - 8usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_8__bindgen_ty_1"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_8__bindgen_ty_1>() - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_8__bindgen_ty_1::longmode"][::std::mem::offset_of!(
        kvm_run__bindgen_ty_1__bindgen_ty_8__bindgen_ty_1,
        longmode
    ) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_8__bindgen_ty_1::flags"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_8__bindgen_ty_1, flags) - 0usize];
};
impl Default for kvm_run__bindgen_ty_1__bindgen_ty_8__bindgen_ty_1 {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_run__bindgen_ty_1__bindgen_ty_8__bindgen_ty_1 {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write!(
            f,
            "kvm_run__bindgen_ty_1__bindgen_ty_8__bindgen_ty_1 {{ union }}"
        )
    }
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_8"]
        [::std::mem::size_of::<kvm_run__bindgen_ty_1__bindgen_ty_8>() - 72usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_8"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_8>() - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_8::nr"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_8, nr) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_8::args"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_8, args) - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_8::ret"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_8, ret) - 56usize];
};
impl Default for kvm_run__bindgen_ty_1__bindgen_ty_8 {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_run__bindgen_ty_1__bindgen_ty_8 {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write ! (f , "kvm_run__bindgen_ty_1__bindgen_ty_8 {{ nr: {:?}, args: {:?}, ret: {:?}, __bindgen_anon_1: {:?} }}" , self . nr , self . args , self . ret , self . __bindgen_anon_1)
    }
}
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_run__bindgen_ty_1__bindgen_ty_9 {
    pub rip: __u64,
    pub is_write: __u32,
    pub pad: __u32,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_9"]
        [::std::mem::size_of::<kvm_run__bindgen_ty_1__bindgen_ty_9>() - 16usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_9"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_9>() - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_9::rip"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_9, rip) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_9::is_write"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_9, is_write) - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_9::pad"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_9, pad) - 12usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_run__bindgen_ty_1__bindgen_ty_10 {
    pub icptcode: __u8,
    pub ipa: __u16,
    pub ipb: __u32,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_10"]
        [::std::mem::size_of::<kvm_run__bindgen_ty_1__bindgen_ty_10>() - 8usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_10"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_10>() - 4usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_10::icptcode"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_10, icptcode) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_10::ipa"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_10, ipa) - 2usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_10::ipb"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_10, ipb) - 4usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_run__bindgen_ty_1__bindgen_ty_11 {
    pub trans_exc_code: __u64,
    pub pgm_code: __u32,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_11"]
        [::std::mem::size_of::<kvm_run__bindgen_ty_1__bindgen_ty_11>() - 16usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_11"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_11>() - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_11::trans_exc_code"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_11, trans_exc_code) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_11::pgm_code"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_11, pgm_code) - 8usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_run__bindgen_ty_1__bindgen_ty_12 {
    pub dcrn: __u32,
    pub data: __u32,
    pub is_write: __u8,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_12"]
        [::std::mem::size_of::<kvm_run__bindgen_ty_1__bindgen_ty_12>() - 12usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_12"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_12>() - 4usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_12::dcrn"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_12, dcrn) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_12::data"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_12, data) - 4usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_12::is_write"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_12, is_write) - 8usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_run__bindgen_ty_1__bindgen_ty_13 {
    pub suberror: __u32,
    pub ndata: __u32,
    pub data: [__u64; 16usize],
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_13"]
        [::std::mem::size_of::<kvm_run__bindgen_ty_1__bindgen_ty_13>() - 136usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_13"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_13>() - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_13::suberror"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_13, suberror) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_13::ndata"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_13, ndata) - 4usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_13::data"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_13, data) - 8usize];
};
#[repr(C)]
#[derive(Copy, Clone)]
pub struct kvm_run__bindgen_ty_1__bindgen_ty_14 {
    pub suberror: __u32,
    pub ndata: __u32,
    pub flags: __u64,
    pub __bindgen_anon_1: kvm_run__bindgen_ty_1__bindgen_ty_14__bindgen_ty_1,
}
#[repr(C)]
#[derive(Copy, Clone)]
pub union kvm_run__bindgen_ty_1__bindgen_ty_14__bindgen_ty_1 {
    pub __bindgen_anon_1: kvm_run__bindgen_ty_1__bindgen_ty_14__bindgen_ty_1__bindgen_ty_1,
}
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_run__bindgen_ty_1__bindgen_ty_14__bindgen_ty_1__bindgen_ty_1 {
    pub insn_size: __u8,
    pub insn_bytes: [__u8; 15usize],
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_14__bindgen_ty_1__bindgen_ty_1"][::std::mem::size_of::<
        kvm_run__bindgen_ty_1__bindgen_ty_14__bindgen_ty_1__bindgen_ty_1,
    >() - 16usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_14__bindgen_ty_1__bindgen_ty_1"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_14__bindgen_ty_1__bindgen_ty_1>(
        ) - 1usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_14__bindgen_ty_1__bindgen_ty_1::insn_size"] [:: std :: mem :: offset_of ! (kvm_run__bindgen_ty_1__bindgen_ty_14__bindgen_ty_1__bindgen_ty_1 , insn_size) - 0usize] ;
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_14__bindgen_ty_1__bindgen_ty_1::insn_bytes"] [:: std :: mem :: offset_of ! (kvm_run__bindgen_ty_1__bindgen_ty_14__bindgen_ty_1__bindgen_ty_1 , insn_bytes) - 1usize] ;
};
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_14__bindgen_ty_1"]
        [::std::mem::size_of::<kvm_run__bindgen_ty_1__bindgen_ty_14__bindgen_ty_1>() - 16usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_14__bindgen_ty_1"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_14__bindgen_ty_1>() - 1usize];
};
impl Default for kvm_run__bindgen_ty_1__bindgen_ty_14__bindgen_ty_1 {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_run__bindgen_ty_1__bindgen_ty_14__bindgen_ty_1 {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write!(
            f,
            "kvm_run__bindgen_ty_1__bindgen_ty_14__bindgen_ty_1 {{ union }}"
        )
    }
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_14"]
        [::std::mem::size_of::<kvm_run__bindgen_ty_1__bindgen_ty_14>() - 32usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_14"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_14>() - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_14::suberror"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_14, suberror) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_14::ndata"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_14, ndata) - 4usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_14::flags"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_14, flags) - 8usize];
};
impl Default for kvm_run__bindgen_ty_1__bindgen_ty_14 {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_run__bindgen_ty_1__bindgen_ty_14 {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write ! (f , "kvm_run__bindgen_ty_1__bindgen_ty_14 {{ suberror: {:?}, ndata: {:?}, flags: {:?}, __bindgen_anon_1: {:?} }}" , self . suberror , self . ndata , self . flags , self . __bindgen_anon_1)
    }
}
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_run__bindgen_ty_1__bindgen_ty_15 {
    pub gprs: [__u64; 32usize],
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_15"]
        [::std::mem::size_of::<kvm_run__bindgen_ty_1__bindgen_ty_15>() - 256usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_15"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_15>() - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_15::gprs"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_15, gprs) - 0usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_run__bindgen_ty_1__bindgen_ty_16 {
    pub nr: __u64,
    pub ret: __u64,
    pub args: [__u64; 9usize],
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_16"]
        [::std::mem::size_of::<kvm_run__bindgen_ty_1__bindgen_ty_16>() - 88usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_16"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_16>() - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_16::nr"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_16, nr) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_16::ret"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_16, ret) - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_16::args"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_16, args) - 16usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_run__bindgen_ty_1__bindgen_ty_17 {
    pub subchannel_id: __u16,
    pub subchannel_nr: __u16,
    pub io_int_parm: __u32,
    pub io_int_word: __u32,
    pub ipb: __u32,
    pub dequeued: __u8,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_17"]
        [::std::mem::size_of::<kvm_run__bindgen_ty_1__bindgen_ty_17>() - 20usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_17"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_17>() - 4usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_17::subchannel_id"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_17, subchannel_id) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_17::subchannel_nr"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_17, subchannel_nr) - 2usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_17::io_int_parm"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_17, io_int_parm) - 4usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_17::io_int_word"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_17, io_int_word) - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_17::ipb"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_17, ipb) - 12usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_17::dequeued"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_17, dequeued) - 16usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_run__bindgen_ty_1__bindgen_ty_18 {
    pub epr: __u32,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_18"]
        [::std::mem::size_of::<kvm_run__bindgen_ty_1__bindgen_ty_18>() - 4usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_18"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_18>() - 4usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_18::epr"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_18, epr) - 0usize];
};
#[repr(C)]
#[derive(Copy, Clone)]
pub struct kvm_run__bindgen_ty_1__bindgen_ty_19 {
    pub type_: __u32,
    pub ndata: __u32,
    pub __bindgen_anon_1: kvm_run__bindgen_ty_1__bindgen_ty_19__bindgen_ty_1,
}
#[repr(C)]
#[derive(Copy, Clone)]
pub union kvm_run__bindgen_ty_1__bindgen_ty_19__bindgen_ty_1 {
    pub flags: __u64,
    pub data: [__u64; 16usize],
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_19__bindgen_ty_1"]
        [::std::mem::size_of::<kvm_run__bindgen_ty_1__bindgen_ty_19__bindgen_ty_1>() - 128usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_19__bindgen_ty_1"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_19__bindgen_ty_1>() - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_19__bindgen_ty_1::flags"][::std::mem::offset_of!(
        kvm_run__bindgen_ty_1__bindgen_ty_19__bindgen_ty_1,
        flags
    ) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_19__bindgen_ty_1::data"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_19__bindgen_ty_1, data) - 0usize];
};
impl Default for kvm_run__bindgen_ty_1__bindgen_ty_19__bindgen_ty_1 {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_run__bindgen_ty_1__bindgen_ty_19__bindgen_ty_1 {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write!(
            f,
            "kvm_run__bindgen_ty_1__bindgen_ty_19__bindgen_ty_1 {{ union }}"
        )
    }
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_19"]
        [::std::mem::size_of::<kvm_run__bindgen_ty_1__bindgen_ty_19>() - 136usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_19"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_19>() - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_19::type_"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_19, type_) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_19::ndata"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_19, ndata) - 4usize];
};
impl Default for kvm_run__bindgen_ty_1__bindgen_ty_19 {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_run__bindgen_ty_1__bindgen_ty_19 {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write ! (f , "kvm_run__bindgen_ty_1__bindgen_ty_19 {{ type: {:?}, ndata: {:?}, __bindgen_anon_1: {:?} }}" , self . type_ , self . ndata , self . __bindgen_anon_1)
    }
}
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_run__bindgen_ty_1__bindgen_ty_20 {
    pub addr: __u64,
    pub ar: __u8,
    pub reserved: __u8,
    pub fc: __u8,
    pub sel1: __u8,
    pub sel2: __u16,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_20"]
        [::std::mem::size_of::<kvm_run__bindgen_ty_1__bindgen_ty_20>() - 16usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_20"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_20>() - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_20::addr"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_20, addr) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_20::ar"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_20, ar) - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_20::reserved"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_20, reserved) - 9usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_20::fc"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_20, fc) - 10usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_20::sel1"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_20, sel1) - 11usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_20::sel2"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_20, sel2) - 12usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_run__bindgen_ty_1__bindgen_ty_21 {
    pub vector: __u8,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_21"]
        [::std::mem::size_of::<kvm_run__bindgen_ty_1__bindgen_ty_21>() - 1usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_21"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_21>() - 1usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_21::vector"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_21, vector) - 0usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_run__bindgen_ty_1__bindgen_ty_22 {
    pub esr_iss: __u64,
    pub fault_ipa: __u64,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_22"]
        [::std::mem::size_of::<kvm_run__bindgen_ty_1__bindgen_ty_22>() - 16usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_22"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_22>() - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_22::esr_iss"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_22, esr_iss) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_22::fault_ipa"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_22, fault_ipa) - 8usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_run__bindgen_ty_1__bindgen_ty_23 {
    pub error: __u8,
    pub pad: [__u8; 7usize],
    pub reason: __u32,
    pub index: __u32,
    pub data: __u64,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_23"]
        [::std::mem::size_of::<kvm_run__bindgen_ty_1__bindgen_ty_23>() - 24usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_23"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_23>() - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_23::error"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_23, error) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_23::pad"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_23, pad) - 1usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_23::reason"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_23, reason) - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_23::index"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_23, index) - 12usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_23::data"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_23, data) - 16usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_run__bindgen_ty_1__bindgen_ty_24 {
    pub extension_id: ::std::os::raw::c_ulong,
    pub function_id: ::std::os::raw::c_ulong,
    pub args: [::std::os::raw::c_ulong; 6usize],
    pub ret: [::std::os::raw::c_ulong; 2usize],
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_24"]
        [::std::mem::size_of::<kvm_run__bindgen_ty_1__bindgen_ty_24>() - 80usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_24"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_24>() - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_24::extension_id"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_24, extension_id) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_24::function_id"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_24, function_id) - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_24::args"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_24, args) - 16usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_24::ret"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_24, ret) - 64usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_run__bindgen_ty_1__bindgen_ty_25 {
    pub csr_num: ::std::os::raw::c_ulong,
    pub new_value: ::std::os::raw::c_ulong,
    pub write_mask: ::std::os::raw::c_ulong,
    pub ret_value: ::std::os::raw::c_ulong,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_25"]
        [::std::mem::size_of::<kvm_run__bindgen_ty_1__bindgen_ty_25>() - 32usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_25"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_25>() - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_25::csr_num"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_25, csr_num) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_25::new_value"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_25, new_value) - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_25::write_mask"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_25, write_mask) - 16usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_25::ret_value"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_25, ret_value) - 24usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_run__bindgen_ty_1__bindgen_ty_26 {
    pub flags: __u32,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_26"]
        [::std::mem::size_of::<kvm_run__bindgen_ty_1__bindgen_ty_26>() - 4usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_26"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_26>() - 4usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_26::flags"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_26, flags) - 0usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_run__bindgen_ty_1__bindgen_ty_27 {
    pub flags: __u64,
    pub gpa: __u64,
    pub size: __u64,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1__bindgen_ty_27"]
        [::std::mem::size_of::<kvm_run__bindgen_ty_1__bindgen_ty_27>() - 24usize];
    ["Alignment of kvm_run__bindgen_ty_1__bindgen_ty_27"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1__bindgen_ty_27>() - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_27::flags"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_27, flags) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_27::gpa"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_27, gpa) - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1__bindgen_ty_27::size"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1__bindgen_ty_27, size) - 16usize];
};
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_1"][::std::mem::size_of::<kvm_run__bindgen_ty_1>() - 256usize];
    ["Alignment of kvm_run__bindgen_ty_1"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_1>() - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_1::hw"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, hw) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1::fail_entry"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, fail_entry) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1::ex"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, ex) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1::io"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, io) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1::debug"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, debug) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1::mmio"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, mmio) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1::iocsr_io"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, iocsr_io) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1::hypercall"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, hypercall) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1::tpr_access"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, tpr_access) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1::s390_sieic"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, s390_sieic) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1::s390_reset_flags"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, s390_reset_flags) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1::s390_ucontrol"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, s390_ucontrol) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1::dcr"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, dcr) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1::internal"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, internal) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1::emulation_failure"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, emulation_failure) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1::osi"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, osi) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1::papr_hcall"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, papr_hcall) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1::s390_tsch"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, s390_tsch) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1::epr"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, epr) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1::system_event"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, system_event) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1::s390_stsi"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, s390_stsi) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1::eoi"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, eoi) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1::hyperv"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, hyperv) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1::arm_nisv"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, arm_nisv) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1::msr"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, msr) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1::xen"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, xen) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1::riscv_sbi"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, riscv_sbi) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1::riscv_csr"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, riscv_csr) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1::notify"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, notify) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1::memory_fault"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, memory_fault) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_1::padding"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_1, padding) - 0usize];
};
impl Default for kvm_run__bindgen_ty_1 {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_run__bindgen_ty_1 {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write!(f, "kvm_run__bindgen_ty_1 {{ union }}")
    }
}
#[repr(C)]
#[derive(Copy, Clone)]
pub union kvm_run__bindgen_ty_2 {
    pub regs: kvm_sync_regs,
    pub padding: [::std::os::raw::c_char; 2048usize],
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run__bindgen_ty_2"][::std::mem::size_of::<kvm_run__bindgen_ty_2>() - 2048usize];
    ["Alignment of kvm_run__bindgen_ty_2"]
        [::std::mem::align_of::<kvm_run__bindgen_ty_2>() - 8usize];
    ["Offset of field: kvm_run__bindgen_ty_2::regs"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_2, regs) - 0usize];
    ["Offset of field: kvm_run__bindgen_ty_2::padding"]
        [::std::mem::offset_of!(kvm_run__bindgen_ty_2, padding) - 0usize];
};
impl Default for kvm_run__bindgen_ty_2 {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_run__bindgen_ty_2 {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write!(f, "kvm_run__bindgen_ty_2 {{ union }}")
    }
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_run"][::std::mem::size_of::<kvm_run>() - 2352usize];
    ["Alignment of kvm_run"][::std::mem::align_of::<kvm_run>() - 8usize];
    ["Offset of field: kvm_run::request_interrupt_window"]
        [::std::mem::offset_of!(kvm_run, request_interrupt_window) - 0usize];
    ["Offset of field: kvm_run::immediate_exit"]
        [::std::mem::offset_of!(kvm_run, immediate_exit) - 1usize];
    ["Offset of field: kvm_run::padding1"][::std::mem::offset_of!(kvm_run, padding1) - 2usize];
    ["Offset of field: kvm_run::exit_reason"]
        [::std::mem::offset_of!(kvm_run, exit_reason) - 8usize];
    ["Offset of field: kvm_run::ready_for_interrupt_injection"]
        [::std::mem::offset_of!(kvm_run, ready_for_interrupt_injection) - 12usize];
    ["Offset of field: kvm_run::if_flag"][::std::mem::offset_of!(kvm_run, if_flag) - 13usize];
    ["Offset of field: kvm_run::flags"][::std::mem::offset_of!(kvm_run, flags) - 14usize];
    ["Offset of field: kvm_run::cr8"][::std::mem::offset_of!(kvm_run, cr8) - 16usize];
    ["Offset of field: kvm_run::apic_base"][::std::mem::offset_of!(kvm_run, apic_base) - 24usize];
    ["Offset of field: kvm_run::kvm_valid_regs"]
        [::std::mem::offset_of!(kvm_run, kvm_valid_regs) - 288usize];
    ["Offset of field: kvm_run::kvm_dirty_regs"]
        [::std::mem::offset_of!(kvm_run, kvm_dirty_regs) - 296usize];
    ["Offset of field: kvm_run::s"][::std::mem::offset_of!(kvm_run, s) - 304usize];
};
impl Default for kvm_run {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_run {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write ! (f , "kvm_run {{ request_interrupt_window: {:?}, immediate_exit: {:?}, padding1: {:?}, exit_reason: {:?}, ready_for_interrupt_injection: {:?}, if_flag: {:?}, flags: {:?}, cr8: {:?}, apic_base: {:?}, __bindgen_anon_1: {:?}, kvm_valid_regs: {:?}, kvm_dirty_regs: {:?}, s: {:?} }}" , self . request_interrupt_window , self . immediate_exit , self . padding1 , self . exit_reason , self . ready_for_interrupt_injection , self . if_flag , self . flags , self . cr8 , self . apic_base , self . __bindgen_anon_1 , self . kvm_valid_regs , self . kvm_dirty_regs , self . s)
    }
}
#[repr(C)]
#[derive(Copy, Clone)]
pub struct kvm_coalesced_mmio_zone {
    pub addr: __u64,
    pub size: __u32,
    pub __bindgen_anon_1: kvm_coalesced_mmio_zone__bindgen_ty_1,
}
#[repr(C)]
#[derive(Copy, Clone)]
pub union kvm_coalesced_mmio_zone__bindgen_ty_1 {
    pub pad: __u32,
    pub pio: __u32,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_coalesced_mmio_zone__bindgen_ty_1"]
        [::std::mem::size_of::<kvm_coalesced_mmio_zone__bindgen_ty_1>() - 4usize];
    ["Alignment of kvm_coalesced_mmio_zone__bindgen_ty_1"]
        [::std::mem::align_of::<kvm_coalesced_mmio_zone__bindgen_ty_1>() - 4usize];
    ["Offset of field: kvm_coalesced_mmio_zone__bindgen_ty_1::pad"]
        [::std::mem::offset_of!(kvm_coalesced_mmio_zone__bindgen_ty_1, pad) - 0usize];
    ["Offset of field: kvm_coalesced_mmio_zone__bindgen_ty_1::pio"]
        [::std::mem::offset_of!(kvm_coalesced_mmio_zone__bindgen_ty_1, pio) - 0usize];
};
impl Default for kvm_coalesced_mmio_zone__bindgen_ty_1 {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_coalesced_mmio_zone__bindgen_ty_1 {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write!(f, "kvm_coalesced_mmio_zone__bindgen_ty_1 {{ union }}")
    }
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_coalesced_mmio_zone"][::std::mem::size_of::<kvm_coalesced_mmio_zone>() - 16usize];
    ["Alignment of kvm_coalesced_mmio_zone"]
        [::std::mem::align_of::<kvm_coalesced_mmio_zone>() - 8usize];
    ["Offset of field: kvm_coalesced_mmio_zone::addr"]
        [::std::mem::offset_of!(kvm_coalesced_mmio_zone, addr) - 0usize];
    ["Offset of field: kvm_coalesced_mmio_zone::size"]
        [::std::mem::offset_of!(kvm_coalesced_mmio_zone, size) - 8usize];
};
impl Default for kvm_coalesced_mmio_zone {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_coalesced_mmio_zone {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write!(
            f,
            "kvm_coalesced_mmio_zone {{ addr: {:?}, size: {:?}, __bindgen_anon_1: {:?} }}",
            self.addr, self.size, self.__bindgen_anon_1
        )
    }
}
#[repr(C)]
#[derive(Copy, Clone)]
pub struct kvm_coalesced_mmio {
    pub phys_addr: __u64,
    pub len: __u32,
    pub __bindgen_anon_1: kvm_coalesced_mmio__bindgen_ty_1,
    pub data: [__u8; 8usize],
}
#[repr(C)]
#[derive(Copy, Clone)]
pub union kvm_coalesced_mmio__bindgen_ty_1 {
    pub pad: __u32,
    pub pio: __u32,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_coalesced_mmio__bindgen_ty_1"]
        [::std::mem::size_of::<kvm_coalesced_mmio__bindgen_ty_1>() - 4usize];
    ["Alignment of kvm_coalesced_mmio__bindgen_ty_1"]
        [::std::mem::align_of::<kvm_coalesced_mmio__bindgen_ty_1>() - 4usize];
    ["Offset of field: kvm_coalesced_mmio__bindgen_ty_1::pad"]
        [::std::mem::offset_of!(kvm_coalesced_mmio__bindgen_ty_1, pad) - 0usize];
    ["Offset of field: kvm_coalesced_mmio__bindgen_ty_1::pio"]
        [::std::mem::offset_of!(kvm_coalesced_mmio__bindgen_ty_1, pio) - 0usize];
};
impl Default for kvm_coalesced_mmio__bindgen_ty_1 {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_coalesced_mmio__bindgen_ty_1 {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write!(f, "kvm_coalesced_mmio__bindgen_ty_1 {{ union }}")
    }
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_coalesced_mmio"][::std::mem::size_of::<kvm_coalesced_mmio>() - 24usize];
    ["Alignment of kvm_coalesced_mmio"][::std::mem::align_of::<kvm_coalesced_mmio>() - 8usize];
    ["Offset of field: kvm_coalesced_mmio::phys_addr"]
        [::std::mem::offset_of!(kvm_coalesced_mmio, phys_addr) - 0usize];
    ["Offset of field: kvm_coalesced_mmio::len"]
        [::std::mem::offset_of!(kvm_coalesced_mmio, len) - 8usize];
    ["Offset of field: kvm_coalesced_mmio::data"]
        [::std::mem::offset_of!(kvm_coalesced_mmio, data) - 16usize];
};
impl Default for kvm_coalesced_mmio {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_coalesced_mmio {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write ! (f , "kvm_coalesced_mmio {{ phys_addr: {:?}, len: {:?}, __bindgen_anon_1: {:?}, data: {:?} }}" , self . phys_addr , self . len , self . __bindgen_anon_1 , self . data)
    }
}
#[repr(C)]
pub struct kvm_coalesced_mmio_ring {
    pub first: __u32,
    pub last: __u32,
    pub coalesced_mmio: __IncompleteArrayField<kvm_coalesced_mmio>,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_coalesced_mmio_ring"][::std::mem::size_of::<kvm_coalesced_mmio_ring>() - 8usize];
    ["Alignment of kvm_coalesced_mmio_ring"]
        [::std::mem::align_of::<kvm_coalesced_mmio_ring>() - 8usize];
    ["Offset of field: kvm_coalesced_mmio_ring::first"]
        [::std::mem::offset_of!(kvm_coalesced_mmio_ring, first) - 0usize];
    ["Offset of field: kvm_coalesced_mmio_ring::last"]
        [::std::mem::offset_of!(kvm_coalesced_mmio_ring, last) - 4usize];
    ["Offset of field: kvm_coalesced_mmio_ring::coalesced_mmio"]
        [::std::mem::offset_of!(kvm_coalesced_mmio_ring, coalesced_mmio) - 8usize];
};
impl Default for kvm_coalesced_mmio_ring {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_coalesced_mmio_ring {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write!(
            f,
            "kvm_coalesced_mmio_ring {{ first: {:?}, last: {:?}, coalesced_mmio: {:?} }}",
            self.first, self.last, self.coalesced_mmio
        )
    }
}
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_translation {
    pub linear_address: __u64,
    pub physical_address: __u64,
    pub valid: __u8,
    pub writeable: __u8,
    pub usermode: __u8,
    pub pad: [__u8; 5usize],
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_translation"][::std::mem::size_of::<kvm_translation>() - 24usize];
    ["Alignment of kvm_translation"][::std::mem::align_of::<kvm_translation>() - 8usize];
    ["Offset of field: kvm_translation::linear_address"]
        [::std::mem::offset_of!(kvm_translation, linear_address) - 0usize];
    ["Offset of field: kvm_translation::physical_address"]
        [::std::mem::offset_of!(kvm_translation, physical_address) - 8usize];
    ["Offset of field: kvm_translation::valid"]
        [::std::mem::offset_of!(kvm_translation, valid) - 16usize];
    ["Offset of field: kvm_translation::writeable"]
        [::std::mem::offset_of!(kvm_translation, writeable) - 17usize];
    ["Offset of field: kvm_translation::usermode"]
        [::std::mem::offset_of!(kvm_translation, usermode) - 18usize];
    ["Offset of field: kvm_translation::pad"]
        [::std::mem::offset_of!(kvm_translation, pad) - 19usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_interrupt {
    pub irq: __u32,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_interrupt"][::std::mem::size_of::<kvm_interrupt>() - 4usize];
    ["Alignment of kvm_interrupt"][::std::mem::align_of::<kvm_interrupt>() - 4usize];
    ["Offset of field: kvm_interrupt::irq"][::std::mem::offset_of!(kvm_interrupt, irq) - 0usize];
};
#[repr(C)]
#[derive(Copy, Clone)]
pub struct kvm_dirty_log {
    pub slot: __u32,
    pub padding1: __u32,
    pub __bindgen_anon_1: kvm_dirty_log__bindgen_ty_1,
}
#[repr(C)]
#[derive(Copy, Clone)]
pub union kvm_dirty_log__bindgen_ty_1 {
    pub dirty_bitmap: *mut ::std::os::raw::c_void,
    pub padding2: __u64,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_dirty_log__bindgen_ty_1"]
        [::std::mem::size_of::<kvm_dirty_log__bindgen_ty_1>() - 8usize];
    ["Alignment of kvm_dirty_log__bindgen_ty_1"]
        [::std::mem::align_of::<kvm_dirty_log__bindgen_ty_1>() - 8usize];
    ["Offset of field: kvm_dirty_log__bindgen_ty_1::dirty_bitmap"]
        [::std::mem::offset_of!(kvm_dirty_log__bindgen_ty_1, dirty_bitmap) - 0usize];
    ["Offset of field: kvm_dirty_log__bindgen_ty_1::padding2"]
        [::std::mem::offset_of!(kvm_dirty_log__bindgen_ty_1, padding2) - 0usize];
};
impl Default for kvm_dirty_log__bindgen_ty_1 {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_dirty_log__bindgen_ty_1 {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write!(f, "kvm_dirty_log__bindgen_ty_1 {{ union }}")
    }
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_dirty_log"][::std::mem::size_of::<kvm_dirty_log>() - 16usize];
    ["Alignment of kvm_dirty_log"][::std::mem::align_of::<kvm_dirty_log>() - 8usize];
    ["Offset of field: kvm_dirty_log::slot"][::std::mem::offset_of!(kvm_dirty_log, slot) - 0usize];
    ["Offset of field: kvm_dirty_log::padding1"]
        [::std::mem::offset_of!(kvm_dirty_log, padding1) - 4usize];
};
impl Default for kvm_dirty_log {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_dirty_log {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write!(
            f,
            "kvm_dirty_log {{ slot: {:?}, padding1: {:?}, __bindgen_anon_1: {:?} }}",
            self.slot, self.padding1, self.__bindgen_anon_1
        )
    }
}
#[repr(C)]
#[derive(Copy, Clone)]
pub struct kvm_clear_dirty_log {
    pub slot: __u32,
    pub num_pages: __u32,
    pub first_page: __u64,
    pub __bindgen_anon_1: kvm_clear_dirty_log__bindgen_ty_1,
}
#[repr(C)]
#[derive(Copy, Clone)]
pub union kvm_clear_dirty_log__bindgen_ty_1 {
    pub dirty_bitmap: *mut ::std::os::raw::c_void,
    pub padding2: __u64,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_clear_dirty_log__bindgen_ty_1"]
        [::std::mem::size_of::<kvm_clear_dirty_log__bindgen_ty_1>() - 8usize];
    ["Alignment of kvm_clear_dirty_log__bindgen_ty_1"]
        [::std::mem::align_of::<kvm_clear_dirty_log__bindgen_ty_1>() - 8usize];
    ["Offset of field: kvm_clear_dirty_log__bindgen_ty_1::dirty_bitmap"]
        [::std::mem::offset_of!(kvm_clear_dirty_log__bindgen_ty_1, dirty_bitmap) - 0usize];
    ["Offset of field: kvm_clear_dirty_log__bindgen_ty_1::padding2"]
        [::std::mem::offset_of!(kvm_clear_dirty_log__bindgen_ty_1, padding2) - 0usize];
};
impl Default for kvm_clear_dirty_log__bindgen_ty_1 {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_clear_dirty_log__bindgen_ty_1 {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write!(f, "kvm_clear_dirty_log__bindgen_ty_1 {{ union }}")
    }
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_clear_dirty_log"][::std::mem::size_of::<kvm_clear_dirty_log>() - 24usize];
    ["Alignment of kvm_clear_dirty_log"][::std::mem::align_of::<kvm_clear_dirty_log>() - 8usize];
    ["Offset of field: kvm_clear_dirty_log::slot"]
        [::std::mem::offset_of!(kvm_clear_dirty_log, slot) - 0usize];
    ["Offset of field: kvm_clear_dirty_log::num_pages"]
        [::std::mem::offset_of!(kvm_clear_dirty_log, num_pages) - 4usize];
    ["Offset of field: kvm_clear_dirty_log::first_page"]
        [::std::mem::offset_of!(kvm_clear_dirty_log, first_page) - 8usize];
};
impl Default for kvm_clear_dirty_log {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_clear_dirty_log {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write ! (f , "kvm_clear_dirty_log {{ slot: {:?}, num_pages: {:?}, first_page: {:?}, __bindgen_anon_1: {:?} }}" , self . slot , self . num_pages , self . first_page , self . __bindgen_anon_1)
    }
}
#[repr(C)]
#[derive(Debug, Default)]
pub struct kvm_signal_mask {
    pub len: __u32,
    pub sigset: __IncompleteArrayField<__u8>,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_signal_mask"][::std::mem::size_of::<kvm_signal_mask>() - 4usize];
    ["Alignment of kvm_signal_mask"][::std::mem::align_of::<kvm_signal_mask>() - 4usize];
    ["Offset of field: kvm_signal_mask::len"]
        [::std::mem::offset_of!(kvm_signal_mask, len) - 0usize];
    ["Offset of field: kvm_signal_mask::sigset"]
        [::std::mem::offset_of!(kvm_signal_mask, sigset) - 4usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_tpr_access_ctl {
    pub enabled: __u32,
    pub flags: __u32,
    pub reserved: [__u32; 8usize],
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_tpr_access_ctl"][::std::mem::size_of::<kvm_tpr_access_ctl>() - 40usize];
    ["Alignment of kvm_tpr_access_ctl"][::std::mem::align_of::<kvm_tpr_access_ctl>() - 4usize];
    ["Offset of field: kvm_tpr_access_ctl::enabled"]
        [::std::mem::offset_of!(kvm_tpr_access_ctl, enabled) - 0usize];
    ["Offset of field: kvm_tpr_access_ctl::flags"]
        [::std::mem::offset_of!(kvm_tpr_access_ctl, flags) - 4usize];
    ["Offset of field: kvm_tpr_access_ctl::reserved"]
        [::std::mem::offset_of!(kvm_tpr_access_ctl, reserved) - 8usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_vapic_addr {
    pub vapic_addr: __u64,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_vapic_addr"][::std::mem::size_of::<kvm_vapic_addr>() - 8usize];
    ["Alignment of kvm_vapic_addr"][::std::mem::align_of::<kvm_vapic_addr>() - 8usize];
    ["Offset of field: kvm_vapic_addr::vapic_addr"]
        [::std::mem::offset_of!(kvm_vapic_addr, vapic_addr) - 0usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
#[cfg_attr(
    feature = "serde",
    derive(zerocopy::AsBytes, zerocopy::FromBytes, zerocopy::FromZeroes)
)]
pub struct kvm_mp_state {
    pub mp_state: __u32,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_mp_state"][::std::mem::size_of::<kvm_mp_state>() - 4usize];
    ["Alignment of kvm_mp_state"][::std::mem::align_of::<kvm_mp_state>() - 4usize];
    ["Offset of field: kvm_mp_state::mp_state"]
        [::std::mem::offset_of!(kvm_mp_state, mp_state) - 0usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_guest_debug {
    pub control: __u32,
    pub pad: __u32,
    pub arch: kvm_guest_debug_arch,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_guest_debug"][::std::mem::size_of::<kvm_guest_debug>() - 520usize];
    ["Alignment of kvm_guest_debug"][::std::mem::align_of::<kvm_guest_debug>() - 8usize];
    ["Offset of field: kvm_guest_debug::control"]
        [::std::mem::offset_of!(kvm_guest_debug, control) - 0usize];
    ["Offset of field: kvm_guest_debug::pad"]
        [::std::mem::offset_of!(kvm_guest_debug, pad) - 4usize];
    ["Offset of field: kvm_guest_debug::arch"]
        [::std::mem::offset_of!(kvm_guest_debug, arch) - 8usize];
};
pub const kvm_ioeventfd_flag_nr_datamatch: _bindgen_ty_4 = 0;
pub const kvm_ioeventfd_flag_nr_pio: _bindgen_ty_4 = 1;
pub const kvm_ioeventfd_flag_nr_deassign: _bindgen_ty_4 = 2;
pub const kvm_ioeventfd_flag_nr_virtio_ccw_notify: _bindgen_ty_4 = 3;
pub const kvm_ioeventfd_flag_nr_fast_mmio: _bindgen_ty_4 = 4;
pub const kvm_ioeventfd_flag_nr_max: _bindgen_ty_4 = 5;
pub type _bindgen_ty_4 = ::std::os::raw::c_uint;
#[repr(C)]
#[derive(Debug, Copy, Clone, PartialEq)]
pub struct kvm_ioeventfd {
    pub datamatch: __u64,
    pub addr: __u64,
    pub len: __u32,
    pub fd: __s32,
    pub flags: __u32,
    pub pad: [__u8; 36usize],
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_ioeventfd"][::std::mem::size_of::<kvm_ioeventfd>() - 64usize];
    ["Alignment of kvm_ioeventfd"][::std::mem::align_of::<kvm_ioeventfd>() - 8usize];
    ["Offset of field: kvm_ioeventfd::datamatch"]
        [::std::mem::offset_of!(kvm_ioeventfd, datamatch) - 0usize];
    ["Offset of field: kvm_ioeventfd::addr"][::std::mem::offset_of!(kvm_ioeventfd, addr) - 8usize];
    ["Offset of field: kvm_ioeventfd::len"][::std::mem::offset_of!(kvm_ioeventfd, len) - 16usize];
    ["Offset of field: kvm_ioeventfd::fd"][::std::mem::offset_of!(kvm_ioeventfd, fd) - 20usize];
    ["Offset of field: kvm_ioeventfd::flags"]
        [::std::mem::offset_of!(kvm_ioeventfd, flags) - 24usize];
    ["Offset of field: kvm_ioeventfd::pad"][::std::mem::offset_of!(kvm_ioeventfd, pad) - 28usize];
};
impl Default for kvm_ioeventfd {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
#[repr(C)]
#[derive(Debug, Copy, Clone, PartialEq)]
pub struct kvm_enable_cap {
    pub cap: __u32,
    pub flags: __u32,
    pub args: [__u64; 4usize],
    pub pad: [__u8; 64usize],
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_enable_cap"][::std::mem::size_of::<kvm_enable_cap>() - 104usize];
    ["Alignment of kvm_enable_cap"][::std::mem::align_of::<kvm_enable_cap>() - 8usize];
    ["Offset of field: kvm_enable_cap::cap"][::std::mem::offset_of!(kvm_enable_cap, cap) - 0usize];
    ["Offset of field: kvm_enable_cap::flags"]
        [::std::mem::offset_of!(kvm_enable_cap, flags) - 4usize];
    ["Offset of field: kvm_enable_cap::args"]
        [::std::mem::offset_of!(kvm_enable_cap, args) - 8usize];
    ["Offset of field: kvm_enable_cap::pad"][::std::mem::offset_of!(kvm_enable_cap, pad) - 40usize];
};
impl Default for kvm_enable_cap {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_irq_routing_irqchip {
    pub irqchip: __u32,
    pub pin: __u32,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_irq_routing_irqchip"][::std::mem::size_of::<kvm_irq_routing_irqchip>() - 8usize];
    ["Alignment of kvm_irq_routing_irqchip"]
        [::std::mem::align_of::<kvm_irq_routing_irqchip>() - 4usize];
    ["Offset of field: kvm_irq_routing_irqchip::irqchip"]
        [::std::mem::offset_of!(kvm_irq_routing_irqchip, irqchip) - 0usize];
    ["Offset of field: kvm_irq_routing_irqchip::pin"]
        [::std::mem::offset_of!(kvm_irq_routing_irqchip, pin) - 4usize];
};
#[repr(C)]
#[derive(Copy, Clone)]
pub struct kvm_irq_routing_msi {
    pub address_lo: __u32,
    pub address_hi: __u32,
    pub data: __u32,
    pub __bindgen_anon_1: kvm_irq_routing_msi__bindgen_ty_1,
}
#[repr(C)]
#[derive(Copy, Clone)]
pub union kvm_irq_routing_msi__bindgen_ty_1 {
    pub pad: __u32,
    pub devid: __u32,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_irq_routing_msi__bindgen_ty_1"]
        [::std::mem::size_of::<kvm_irq_routing_msi__bindgen_ty_1>() - 4usize];
    ["Alignment of kvm_irq_routing_msi__bindgen_ty_1"]
        [::std::mem::align_of::<kvm_irq_routing_msi__bindgen_ty_1>() - 4usize];
    ["Offset of field: kvm_irq_routing_msi__bindgen_ty_1::pad"]
        [::std::mem::offset_of!(kvm_irq_routing_msi__bindgen_ty_1, pad) - 0usize];
    ["Offset of field: kvm_irq_routing_msi__bindgen_ty_1::devid"]
        [::std::mem::offset_of!(kvm_irq_routing_msi__bindgen_ty_1, devid) - 0usize];
};
impl Default for kvm_irq_routing_msi__bindgen_ty_1 {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_irq_routing_msi__bindgen_ty_1 {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write!(f, "kvm_irq_routing_msi__bindgen_ty_1 {{ union }}")
    }
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_irq_routing_msi"][::std::mem::size_of::<kvm_irq_routing_msi>() - 16usize];
    ["Alignment of kvm_irq_routing_msi"][::std::mem::align_of::<kvm_irq_routing_msi>() - 4usize];
    ["Offset of field: kvm_irq_routing_msi::address_lo"]
        [::std::mem::offset_of!(kvm_irq_routing_msi, address_lo) - 0usize];
    ["Offset of field: kvm_irq_routing_msi::address_hi"]
        [::std::mem::offset_of!(kvm_irq_routing_msi, address_hi) - 4usize];
    ["Offset of field: kvm_irq_routing_msi::data"]
        [::std::mem::offset_of!(kvm_irq_routing_msi, data) - 8usize];
};
impl Default for kvm_irq_routing_msi {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_irq_routing_msi {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write ! (f , "kvm_irq_routing_msi {{ address_lo: {:?}, address_hi: {:?}, data: {:?}, __bindgen_anon_1: {:?} }}" , self . address_lo , self . address_hi , self . data , self . __bindgen_anon_1)
    }
}
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_irq_routing_s390_adapter {
    pub ind_addr: __u64,
    pub summary_addr: __u64,
    pub ind_offset: __u64,
    pub summary_offset: __u32,
    pub adapter_id: __u32,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_irq_routing_s390_adapter"]
        [::std::mem::size_of::<kvm_irq_routing_s390_adapter>() - 32usize];
    ["Alignment of kvm_irq_routing_s390_adapter"]
        [::std::mem::align_of::<kvm_irq_routing_s390_adapter>() - 8usize];
    ["Offset of field: kvm_irq_routing_s390_adapter::ind_addr"]
        [::std::mem::offset_of!(kvm_irq_routing_s390_adapter, ind_addr) - 0usize];
    ["Offset of field: kvm_irq_routing_s390_adapter::summary_addr"]
        [::std::mem::offset_of!(kvm_irq_routing_s390_adapter, summary_addr) - 8usize];
    ["Offset of field: kvm_irq_routing_s390_adapter::ind_offset"]
        [::std::mem::offset_of!(kvm_irq_routing_s390_adapter, ind_offset) - 16usize];
    ["Offset of field: kvm_irq_routing_s390_adapter::summary_offset"]
        [::std::mem::offset_of!(kvm_irq_routing_s390_adapter, summary_offset) - 24usize];
    ["Offset of field: kvm_irq_routing_s390_adapter::adapter_id"]
        [::std::mem::offset_of!(kvm_irq_routing_s390_adapter, adapter_id) - 28usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_irq_routing_hv_sint {
    pub vcpu: __u32,
    pub sint: __u32,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_irq_routing_hv_sint"][::std::mem::size_of::<kvm_irq_routing_hv_sint>() - 8usize];
    ["Alignment of kvm_irq_routing_hv_sint"]
        [::std::mem::align_of::<kvm_irq_routing_hv_sint>() - 4usize];
    ["Offset of field: kvm_irq_routing_hv_sint::vcpu"]
        [::std::mem::offset_of!(kvm_irq_routing_hv_sint, vcpu) - 0usize];
    ["Offset of field: kvm_irq_routing_hv_sint::sint"]
        [::std::mem::offset_of!(kvm_irq_routing_hv_sint, sint) - 4usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_irq_routing_xen_evtchn {
    pub port: __u32,
    pub vcpu: __u32,
    pub priority: __u32,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_irq_routing_xen_evtchn"]
        [::std::mem::size_of::<kvm_irq_routing_xen_evtchn>() - 12usize];
    ["Alignment of kvm_irq_routing_xen_evtchn"]
        [::std::mem::align_of::<kvm_irq_routing_xen_evtchn>() - 4usize];
    ["Offset of field: kvm_irq_routing_xen_evtchn::port"]
        [::std::mem::offset_of!(kvm_irq_routing_xen_evtchn, port) - 0usize];
    ["Offset of field: kvm_irq_routing_xen_evtchn::vcpu"]
        [::std::mem::offset_of!(kvm_irq_routing_xen_evtchn, vcpu) - 4usize];
    ["Offset of field: kvm_irq_routing_xen_evtchn::priority"]
        [::std::mem::offset_of!(kvm_irq_routing_xen_evtchn, priority) - 8usize];
};
#[repr(C)]
#[derive(Copy, Clone)]
pub struct kvm_irq_routing_entry {
    pub gsi: __u32,
    pub type_: __u32,
    pub flags: __u32,
    pub pad: __u32,
    pub u: kvm_irq_routing_entry__bindgen_ty_1,
}
#[repr(C)]
#[derive(Copy, Clone)]
pub union kvm_irq_routing_entry__bindgen_ty_1 {
    pub irqchip: kvm_irq_routing_irqchip,
    pub msi: kvm_irq_routing_msi,
    pub adapter: kvm_irq_routing_s390_adapter,
    pub hv_sint: kvm_irq_routing_hv_sint,
    pub xen_evtchn: kvm_irq_routing_xen_evtchn,
    pub pad: [__u32; 8usize],
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_irq_routing_entry__bindgen_ty_1"]
        [::std::mem::size_of::<kvm_irq_routing_entry__bindgen_ty_1>() - 32usize];
    ["Alignment of kvm_irq_routing_entry__bindgen_ty_1"]
        [::std::mem::align_of::<kvm_irq_routing_entry__bindgen_ty_1>() - 8usize];
    ["Offset of field: kvm_irq_routing_entry__bindgen_ty_1::irqchip"]
        [::std::mem::offset_of!(kvm_irq_routing_entry__bindgen_ty_1, irqchip) - 0usize];
    ["Offset of field: kvm_irq_routing_entry__bindgen_ty_1::msi"]
        [::std::mem::offset_of!(kvm_irq_routing_entry__bindgen_ty_1, msi) - 0usize];
    ["Offset of field: kvm_irq_routing_entry__bindgen_ty_1::adapter"]
        [::std::mem::offset_of!(kvm_irq_routing_entry__bindgen_ty_1, adapter) - 0usize];
    ["Offset of field: kvm_irq_routing_entry__bindgen_ty_1::hv_sint"]
        [::std::mem::offset_of!(kvm_irq_routing_entry__bindgen_ty_1, hv_sint) - 0usize];
    ["Offset of field: kvm_irq_routing_entry__bindgen_ty_1::xen_evtchn"]
        [::std::mem::offset_of!(kvm_irq_routing_entry__bindgen_ty_1, xen_evtchn) - 0usize];
    ["Offset of field: kvm_irq_routing_entry__bindgen_ty_1::pad"]
        [::std::mem::offset_of!(kvm_irq_routing_entry__bindgen_ty_1, pad) - 0usize];
};
impl Default for kvm_irq_routing_entry__bindgen_ty_1 {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_irq_routing_entry__bindgen_ty_1 {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write!(f, "kvm_irq_routing_entry__bindgen_ty_1 {{ union }}")
    }
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_irq_routing_entry"][::std::mem::size_of::<kvm_irq_routing_entry>() - 48usize];
    ["Alignment of kvm_irq_routing_entry"]
        [::std::mem::align_of::<kvm_irq_routing_entry>() - 8usize];
    ["Offset of field: kvm_irq_routing_entry::gsi"]
        [::std::mem::offset_of!(kvm_irq_routing_entry, gsi) - 0usize];
    ["Offset of field: kvm_irq_routing_entry::type_"]
        [::std::mem::offset_of!(kvm_irq_routing_entry, type_) - 4usize];
    ["Offset of field: kvm_irq_routing_entry::flags"]
        [::std::mem::offset_of!(kvm_irq_routing_entry, flags) - 8usize];
    ["Offset of field: kvm_irq_routing_entry::pad"]
        [::std::mem::offset_of!(kvm_irq_routing_entry, pad) - 12usize];
    ["Offset of field: kvm_irq_routing_entry::u"]
        [::std::mem::offset_of!(kvm_irq_routing_entry, u) - 16usize];
};
impl Default for kvm_irq_routing_entry {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_irq_routing_entry {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write!(
            f,
            "kvm_irq_routing_entry {{ gsi: {:?}, type: {:?}, flags: {:?}, pad: {:?}, u: {:?} }}",
            self.gsi, self.type_, self.flags, self.pad, self.u
        )
    }
}
#[repr(C)]
pub struct kvm_irq_routing {
    pub nr: __u32,
    pub flags: __u32,
    pub entries: __IncompleteArrayField<kvm_irq_routing_entry>,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_irq_routing"][::std::mem::size_of::<kvm_irq_routing>() - 8usize];
    ["Alignment of kvm_irq_routing"][::std::mem::align_of::<kvm_irq_routing>() - 8usize];
    ["Offset of field: kvm_irq_routing::nr"][::std::mem::offset_of!(kvm_irq_routing, nr) - 0usize];
    ["Offset of field: kvm_irq_routing::flags"]
        [::std::mem::offset_of!(kvm_irq_routing, flags) - 4usize];
    ["Offset of field: kvm_irq_routing::entries"]
        [::std::mem::offset_of!(kvm_irq_routing, entries) - 8usize];
};
impl Default for kvm_irq_routing {
    fn default() -> Self {
        let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
        unsafe {
            ::std::ptr::write_bytes(s.as_mut_ptr(), 0, 1);
            s.assume_init()
        }
    }
}
impl ::std::fmt::Debug for kvm_irq_routing {
    fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
        write!(
            f,
            "kvm_irq_routing {{ nr: {:?}, flags: {:?}, entries: {:?} }}",
            self.nr, self.flags, self.entries
        )
    }
}
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_irqfd {
    pub fd: __u32,
    pub gsi: __u32,
    pub flags: __u32,
    pub resamplefd: __u32,
    pub pad: [__u8; 16usize],
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_irqfd"][::std::mem::size_of::<kvm_irqfd>() - 32usize];
    ["Alignment of kvm_irqfd"][::std::mem::align_of::<kvm_irqfd>() - 4usize];
    ["Offset of field: kvm_irqfd::fd"][::std::mem::offset_of!(kvm_irqfd, fd) - 0usize];
    ["Offset of field: kvm_irqfd::gsi"][::std::mem::offset_of!(kvm_irqfd, gsi) - 4usize];
    ["Offset of field: kvm_irqfd::flags"][::std::mem::offset_of!(kvm_irqfd, flags) - 8usize];
    ["Offset of field: kvm_irqfd::resamplefd"]
        [::std::mem::offset_of!(kvm_irqfd, resamplefd) - 12usize];
    ["Offset of field: kvm_irqfd::pad"][::std::mem::offset_of!(kvm_irqfd, pad) - 16usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_clock_data {
    pub clock: __u64,
    pub flags: __u32,
    pub pad0: __u32,
    pub realtime: __u64,
    pub host_tsc: __u64,
    pub pad: [__u32; 4usize],
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_clock_data"][::std::mem::size_of::<kvm_clock_data>() - 48usize];
    ["Alignment of kvm_clock_data"][::std::mem::align_of::<kvm_clock_data>() - 8usize];
    ["Offset of field: kvm_clock_data::clock"]
        [::std::mem::offset_of!(kvm_clock_data, clock) - 0usize];
    ["Offset of field: kvm_clock_data::flags"]
        [::std::mem::offset_of!(kvm_clock_data, flags) - 8usize];
    ["Offset of field: kvm_clock_data::pad0"]
        [::std::mem::offset_of!(kvm_clock_data, pad0) - 12usize];
    ["Offset of field: kvm_clock_data::realtime"]
        [::std::mem::offset_of!(kvm_clock_data, realtime) - 16usize];
    ["Offset of field: kvm_clock_data::host_tsc"]
        [::std::mem::offset_of!(kvm_clock_data, host_tsc) - 24usize];
    ["Offset of field: kvm_clock_data::pad"][::std::mem::offset_of!(kvm_clock_data, pad) - 32usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_config_tlb {
    pub params: __u64,
    pub array: __u64,
    pub mmu_type: __u32,
    pub array_len: __u32,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_config_tlb"][::std::mem::size_of::<kvm_config_tlb>() - 24usize];
    ["Alignment of kvm_config_tlb"][::std::mem::align_of::<kvm_config_tlb>() - 8usize];
    ["Offset of field: kvm_config_tlb::params"]
        [::std::mem::offset_of!(kvm_config_tlb, params) - 0usize];
    ["Offset of field: kvm_config_tlb::array"]
        [::std::mem::offset_of!(kvm_config_tlb, array) - 8usize];
    ["Offset of field: kvm_config_tlb::mmu_type"]
        [::std::mem::offset_of!(kvm_config_tlb, mmu_type) - 16usize];
    ["Offset of field: kvm_config_tlb::array_len"]
        [::std::mem::offset_of!(kvm_config_tlb, array_len) - 20usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_dirty_tlb {
    pub bitmap: __u64,
    pub num_dirty: __u32,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_dirty_tlb"][::std::mem::size_of::<kvm_dirty_tlb>() - 16usize];
    ["Alignment of kvm_dirty_tlb"][::std::mem::align_of::<kvm_dirty_tlb>() - 8usize];
    ["Offset of field: kvm_dirty_tlb::bitmap"]
        [::std::mem::offset_of!(kvm_dirty_tlb, bitmap) - 0usize];
    ["Offset of field: kvm_dirty_tlb::num_dirty"]
        [::std::mem::offset_of!(kvm_dirty_tlb, num_dirty) - 8usize];
};
#[repr(C)]
#[derive(Debug, Default)]
pub struct kvm_reg_list {
    pub n: __u64,
    pub reg: __IncompleteArrayField<__u64>,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_reg_list"][::std::mem::size_of::<kvm_reg_list>() - 8usize];
    ["Alignment of kvm_reg_list"][::std::mem::align_of::<kvm_reg_list>() - 8usize];
    ["Offset of field: kvm_reg_list::n"][::std::mem::offset_of!(kvm_reg_list, n) - 0usize];
    ["Offset of field: kvm_reg_list::reg"][::std::mem::offset_of!(kvm_reg_list, reg) - 8usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
#[cfg_attr(
    feature = "serde",
    derive(zerocopy::AsBytes, zerocopy::FromBytes, zerocopy::FromZeroes)
)]
pub struct kvm_one_reg {
    pub id: __u64,
    pub addr: __u64,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_one_reg"][::std::mem::size_of::<kvm_one_reg>() - 16usize];
    ["Alignment of kvm_one_reg"][::std::mem::align_of::<kvm_one_reg>() - 8usize];
    ["Offset of field: kvm_one_reg::id"][::std::mem::offset_of!(kvm_one_reg, id) - 0usize];
    ["Offset of field: kvm_one_reg::addr"][::std::mem::offset_of!(kvm_one_reg, addr) - 8usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_msi {
    pub address_lo: __u32,
    pub address_hi: __u32,
    pub data: __u32,
    pub flags: __u32,
    pub devid: __u32,
    pub pad: [__u8; 12usize],
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_msi"][::std::mem::size_of::<kvm_msi>() - 32usize];
    ["Alignment of kvm_msi"][::std::mem::align_of::<kvm_msi>() - 4usize];
    ["Offset of field: kvm_msi::address_lo"][::std::mem::offset_of!(kvm_msi, address_lo) - 0usize];
    ["Offset of field: kvm_msi::address_hi"][::std::mem::offset_of!(kvm_msi, address_hi) - 4usize];
    ["Offset of field: kvm_msi::data"][::std::mem::offset_of!(kvm_msi, data) - 8usize];
    ["Offset of field: kvm_msi::flags"][::std::mem::offset_of!(kvm_msi, flags) - 12usize];
    ["Offset of field: kvm_msi::devid"][::std::mem::offset_of!(kvm_msi, devid) - 16usize];
    ["Offset of field: kvm_msi::pad"][::std::mem::offset_of!(kvm_msi, pad) - 20usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_arm_device_addr {
    pub id: __u64,
    pub addr: __u64,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_arm_device_addr"][::std::mem::size_of::<kvm_arm_device_addr>() - 16usize];
    ["Alignment of kvm_arm_device_addr"][::std::mem::align_of::<kvm_arm_device_addr>() - 8usize];
    ["Offset of field: kvm_arm_device_addr::id"]
        [::std::mem::offset_of!(kvm_arm_device_addr, id) - 0usize];
    ["Offset of field: kvm_arm_device_addr::addr"]
        [::std::mem::offset_of!(kvm_arm_device_addr, addr) - 8usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_create_device {
    pub type_: __u32,
    pub fd: __u32,
    pub flags: __u32,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_create_device"][::std::mem::size_of::<kvm_create_device>() - 12usize];
    ["Alignment of kvm_create_device"][::std::mem::align_of::<kvm_create_device>() - 4usize];
    ["Offset of field: kvm_create_device::type_"]
        [::std::mem::offset_of!(kvm_create_device, type_) - 0usize];
    ["Offset of field: kvm_create_device::fd"]
        [::std::mem::offset_of!(kvm_create_device, fd) - 4usize];
    ["Offset of field: kvm_create_device::flags"]
        [::std::mem::offset_of!(kvm_create_device, flags) - 8usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_device_attr {
    pub flags: __u32,
    pub group: __u32,
    pub attr: __u64,
    pub addr: __u64,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_device_attr"][::std::mem::size_of::<kvm_device_attr>() - 24usize];
    ["Alignment of kvm_device_attr"][::std::mem::align_of::<kvm_device_attr>() - 8usize];
    ["Offset of field: kvm_device_attr::flags"]
        [::std::mem::offset_of!(kvm_device_attr, flags) - 0usize];
    ["Offset of field: kvm_device_attr::group"]
        [::std::mem::offset_of!(kvm_device_attr, group) - 4usize];
    ["Offset of field: kvm_device_attr::attr"]
        [::std::mem::offset_of!(kvm_device_attr, attr) - 8usize];
    ["Offset of field: kvm_device_attr::addr"]
        [::std::mem::offset_of!(kvm_device_attr, addr) - 16usize];
};
pub const kvm_device_type_KVM_DEV_TYPE_FSL_MPIC_20: kvm_device_type = 1;
pub const kvm_device_type_KVM_DEV_TYPE_FSL_MPIC_42: kvm_device_type = 2;
pub const kvm_device_type_KVM_DEV_TYPE_XICS: kvm_device_type = 3;
pub const kvm_device_type_KVM_DEV_TYPE_VFIO: kvm_device_type = 4;
pub const kvm_device_type_KVM_DEV_TYPE_ARM_VGIC_V2: kvm_device_type = 5;
pub const kvm_device_type_KVM_DEV_TYPE_FLIC: kvm_device_type = 6;
pub const kvm_device_type_KVM_DEV_TYPE_ARM_VGIC_V3: kvm_device_type = 7;
pub const kvm_device_type_KVM_DEV_TYPE_ARM_VGIC_ITS: kvm_device_type = 8;
pub const kvm_device_type_KVM_DEV_TYPE_XIVE: kvm_device_type = 9;
pub const kvm_device_type_KVM_DEV_TYPE_ARM_PV_TIME: kvm_device_type = 10;
pub const kvm_device_type_KVM_DEV_TYPE_RISCV_AIA: kvm_device_type = 11;
pub const kvm_device_type_KVM_DEV_TYPE_MAX: kvm_device_type = 12;
pub type kvm_device_type = ::std::os::raw::c_uint;
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_vfio_spapr_tce {
    pub groupfd: __s32,
    pub tablefd: __s32,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_vfio_spapr_tce"][::std::mem::size_of::<kvm_vfio_spapr_tce>() - 8usize];
    ["Alignment of kvm_vfio_spapr_tce"][::std::mem::align_of::<kvm_vfio_spapr_tce>() - 4usize];
    ["Offset of field: kvm_vfio_spapr_tce::groupfd"]
        [::std::mem::offset_of!(kvm_vfio_spapr_tce, groupfd) - 0usize];
    ["Offset of field: kvm_vfio_spapr_tce::tablefd"]
        [::std::mem::offset_of!(kvm_vfio_spapr_tce, tablefd) - 4usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_enc_region {
    pub addr: __u64,
    pub size: __u64,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_enc_region"][::std::mem::size_of::<kvm_enc_region>() - 16usize];
    ["Alignment of kvm_enc_region"][::std::mem::align_of::<kvm_enc_region>() - 8usize];
    ["Offset of field: kvm_enc_region::addr"]
        [::std::mem::offset_of!(kvm_enc_region, addr) - 0usize];
    ["Offset of field: kvm_enc_region::size"]
        [::std::mem::offset_of!(kvm_enc_region, size) - 8usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_dirty_gfn {
    pub flags: __u32,
    pub slot: __u32,
    pub offset: __u64,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_dirty_gfn"][::std::mem::size_of::<kvm_dirty_gfn>() - 16usize];
    ["Alignment of kvm_dirty_gfn"][::std::mem::align_of::<kvm_dirty_gfn>() - 8usize];
    ["Offset of field: kvm_dirty_gfn::flags"]
        [::std::mem::offset_of!(kvm_dirty_gfn, flags) - 0usize];
    ["Offset of field: kvm_dirty_gfn::slot"][::std::mem::offset_of!(kvm_dirty_gfn, slot) - 4usize];
    ["Offset of field: kvm_dirty_gfn::offset"]
        [::std::mem::offset_of!(kvm_dirty_gfn, offset) - 8usize];
};
#[doc = " struct kvm_stats_header - Header of per vm/vcpu binary statistics data.\n @flags: Some extra information for header, always 0 for now.\n @name_size: The size in bytes of the memory which contains statistics\n             name string including trailing '\\0'. The memory is allocated\n             at the send of statistics descriptor.\n @num_desc: The number of statistics the vm or vcpu has.\n @id_offset: The offset of the vm/vcpu stats' id string in the file pointed\n             by vm/vcpu stats fd.\n @desc_offset: The offset of the vm/vcpu stats' descriptor block in the file\n               pointd by vm/vcpu stats fd.\n @data_offset: The offset of the vm/vcpu stats' data block in the file\n               pointed by vm/vcpu stats fd.\n\n This is the header userspace needs to read from stats fd before any other\n readings. It is used by userspace to discover all the information about the\n vm/vcpu's binary statistics.\n Userspace reads this header from the start of the vm/vcpu's stats fd."]
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_stats_header {
    pub flags: __u32,
    pub name_size: __u32,
    pub num_desc: __u32,
    pub id_offset: __u32,
    pub desc_offset: __u32,
    pub data_offset: __u32,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_stats_header"][::std::mem::size_of::<kvm_stats_header>() - 24usize];
    ["Alignment of kvm_stats_header"][::std::mem::align_of::<kvm_stats_header>() - 4usize];
    ["Offset of field: kvm_stats_header::flags"]
        [::std::mem::offset_of!(kvm_stats_header, flags) - 0usize];
    ["Offset of field: kvm_stats_header::name_size"]
        [::std::mem::offset_of!(kvm_stats_header, name_size) - 4usize];
    ["Offset of field: kvm_stats_header::num_desc"]
        [::std::mem::offset_of!(kvm_stats_header, num_desc) - 8usize];
    ["Offset of field: kvm_stats_header::id_offset"]
        [::std::mem::offset_of!(kvm_stats_header, id_offset) - 12usize];
    ["Offset of field: kvm_stats_header::desc_offset"]
        [::std::mem::offset_of!(kvm_stats_header, desc_offset) - 16usize];
    ["Offset of field: kvm_stats_header::data_offset"]
        [::std::mem::offset_of!(kvm_stats_header, data_offset) - 20usize];
};
#[doc = " struct kvm_stats_desc - Descriptor of a KVM statistics.\n @flags: Annotations of the stats, like type, unit, etc.\n @exponent: Used together with @flags to determine the unit.\n @size: The number of data items for this stats.\n        Every data item is of type __u64.\n @offset: The offset of the stats to the start of stat structure in\n          structure kvm or kvm_vcpu.\n @bucket_size: A parameter value used for histogram stats. It is only used\n\t\tfor linear histogram stats, specifying the size of the bucket;\n @name: The name string for the stats. Its size is indicated by the\n        &kvm_stats_header->name_size."]
#[repr(C)]
#[derive(Debug, Default)]
pub struct kvm_stats_desc {
    pub flags: __u32,
    pub exponent: __s16,
    pub size: __u16,
    pub offset: __u32,
    pub bucket_size: __u32,
    pub name: __IncompleteArrayField<::std::os::raw::c_char>,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_stats_desc"][::std::mem::size_of::<kvm_stats_desc>() - 16usize];
    ["Alignment of kvm_stats_desc"][::std::mem::align_of::<kvm_stats_desc>() - 4usize];
    ["Offset of field: kvm_stats_desc::flags"]
        [::std::mem::offset_of!(kvm_stats_desc, flags) - 0usize];
    ["Offset of field: kvm_stats_desc::exponent"]
        [::std::mem::offset_of!(kvm_stats_desc, exponent) - 4usize];
    ["Offset of field: kvm_stats_desc::size"]
        [::std::mem::offset_of!(kvm_stats_desc, size) - 6usize];
    ["Offset of field: kvm_stats_desc::offset"]
        [::std::mem::offset_of!(kvm_stats_desc, offset) - 8usize];
    ["Offset of field: kvm_stats_desc::bucket_size"]
        [::std::mem::offset_of!(kvm_stats_desc, bucket_size) - 12usize];
    ["Offset of field: kvm_stats_desc::name"]
        [::std::mem::offset_of!(kvm_stats_desc, name) - 16usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_memory_attributes {
    pub address: __u64,
    pub size: __u64,
    pub attributes: __u64,
    pub flags: __u64,
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_memory_attributes"][::std::mem::size_of::<kvm_memory_attributes>() - 32usize];
    ["Alignment of kvm_memory_attributes"]
        [::std::mem::align_of::<kvm_memory_attributes>() - 8usize];
    ["Offset of field: kvm_memory_attributes::address"]
        [::std::mem::offset_of!(kvm_memory_attributes, address) - 0usize];
    ["Offset of field: kvm_memory_attributes::size"]
        [::std::mem::offset_of!(kvm_memory_attributes, size) - 8usize];
    ["Offset of field: kvm_memory_attributes::attributes"]
        [::std::mem::offset_of!(kvm_memory_attributes, attributes) - 16usize];
    ["Offset of field: kvm_memory_attributes::flags"]
        [::std::mem::offset_of!(kvm_memory_attributes, flags) - 24usize];
};
#[repr(C)]
#[derive(Debug, Default, Copy, Clone, PartialEq)]
pub struct kvm_create_guest_memfd {
    pub size: __u64,
    pub flags: __u64,
    pub reserved: [__u64; 6usize],
}
#[allow(clippy::unnecessary_operation, clippy::identity_op)]
const _: () = {
    ["Size of kvm_create_guest_memfd"][::std::mem::size_of::<kvm_create_guest_memfd>() - 64usize];
    ["Alignment of kvm_create_guest_memfd"]
        [::std::mem::align_of::<kvm_create_guest_memfd>() - 8usize];
    ["Offset of field: kvm_create_guest_memfd::size"]
        [::std::mem::offset_of!(kvm_create_guest_memfd, size) - 0usize];
    ["Offset of field: kvm_create_guest_memfd::flags"]
        [::std::mem::offset_of!(kvm_create_guest_memfd, flags) - 8usize];
    ["Offset of field: kvm_create_guest_memfd::reserved"]
        [::std::mem::offset_of!(kvm_create_guest_memfd, reserved) - 16usize];
};
pub type __uint128_t = u128;
